/**
 * 程序入口配置读取
 * 项目开发时需要的自定义配置
 */
define(function(require, exports, module) {
	var configuration = {
		/*******************************************必配项***************************************************/		
		"isDirectExit": false,
		/**
		 * 项目的默认页面，当在地址栏输入的url不带pageCode（“#!/”至“.html”中间的部分）时进入该配置对应的页面，
		 * 这个参数是不带pageCode时进入默认页面的入参
		 * 默认为：{}
		 */
		"defaultPage": {"pageCode": "account/index", "jsonParam":{}},
		/******************************************选择可配项************************************************/
		/**
		 * 项目模块名，默认为project
		 */
		"projName": "trade",
		/**
		 * 项目中的需要先加载的css样式文件，如果多个，添加在数组里面中，从css目录下写文件路径
		 * 不配默认为：["/css/app_style.css"]
		 */
		"firstLoadCss": ["/css/common.css","/css/otc.css","/css/animate.css","/css/font.css","/css/style.css","/css/style_add.css","/css/more.css"],
		/**
		 * 后台返回结果集出参结构，类似error_no、error_info的出参命名定义，
		 * 防止不同项目的后台的出参命名不一致，以便框架可取配置的值，由项目自己定义，但后台必须统一
		 * 不配默认为：{"error_no": "error_no", "error_info": "error_info"}
		 */
		"resultsParser": {"error_no": "error_no", "error_info": "error_info"},
		/**
		 * 该配置是请求接口被后台拦截器拦截之后返回的错误号对应的处理
		 * 前端根据后台的error_no做的过滤器配置，需要后台配合定义error_no，
		 * 有的需要跳转页面，有的只做提示，提示信息如果后台给出，就取后台提示信息，否则取配置中的error_info字段
		 * 不配默认为：{}
		 */
		"filters": {
			"99": {"pageCode": "account/index", "jsonParam": {}},    //先提升后跳转
			"-999": {"moduleAlias":"sso", "moduleFuncName":"filterLoginOut"}, //用户没有登陆或者登陆超时
			"-985":{"moduleAlias":"common","moduleFuncName":"filterFinance"}//理财账户登录交易
		},
		/**
		 * 整个项目的登录页面
		 * 不配默认为：{}
		 */
		"loginPage": {"pageCode": "account/login", "jsonParam":{}},
		/**
		 * 整个应用的引导页配置
		 * 不配默认为：{}
		 */
		"guidePage": {"pageCode": "", "jsonParam":{}},
		/**
		 * 项目中公用模块的别名配置
		 * 不配默认为：{}
		 */
		"pAlias": {
			"sso":"sso/sso",
			"common":"trade/scripts/common/common",
			"commonFunc":"trade/scripts/common/commonFunc",
			"commonOrder":"trade/scripts/common/commonOrder",
			"changeToPinyin":"trade/scripts/common/changeToPinyin",
			"service_common":"trade/service/scripts/trade/service_common",
			"service_stock":"trade/service/scripts/trade/service_stock",
			"service_hq":"trade/service/scripts/trade/service_hq",
			"service_fund":"trade/service/scripts/trade/service_fund",
			"service_ggt":"trade/service/scripts/trade/service_ggt",
			"service_otc":"trade/service/scripts/trade/service_otc",
			"service_credit":"trade/service/scripts/trade/service_credit",
			"service_finance":"trade/service/scripts/trade/service_finance",
			"service_added":"trade/service/scripts/trade/service_added"
		},
		/**
		 * 跳转页面时做的权限校验，提供在外面的方法
		 * moduleAlias为项目通用模块配置的别名，moduleFuncName方法里面写校验规则，返回true或者false，避免写异步的代码
		 * 不配默认为：{}
		 */
		"checkPermission": {"moduleAlias":"sso", "moduleFuncName":"checkPermission"},
		/**
		 * 第一次加载第一个业务模块前所需要的处理，即启动之后提供给外界初始化的接口，
		 * 这个方法中避免写异步操作，或者保证异步影响其他代码逻辑
		 * moduleAlias为项目通用模块配置的别名，moduleFuncName为执行的方法
		 * 这个配置可以做很多事情，当你从业务模块逻辑上不好实现时，可以考虑这里！！
		 * 不配默认为：{}
		 */
		"firstLoadIntf": {"moduleAlias":"sso", "moduleFuncName":"firstLoadFunc", "isLoad": false},
		/**
		 * 项目中需要调用到的常量、变量这里配置，调用方式，通过require("gconfig").global.*来调用
		 * 不配默认为：{}
		 */
		"global": {
			
			// 需要校验权限的pageCode,这个和notCheckLoginPageCode只能配置一个
            "checkLoginPageCode":"",
            // 不需要权限校验的pageCode，这个和checkLoginPageCode只能配置一个
            "notCheckLoginPageCode":"account/index",	
			"newshareUrl": "http://120.24.73.231:8089/servlet/json",//思迪新股列表
			"HqUrl": "http://183.57.43.60:8080/market/json",   //思迪行情环境
//			"serverPathTrade" : "http://61.178.68.153:8080/servlet/json", // 华龙证券
//			"validateimg" : "http://61.178.68.153:8080/servlet/NewImage",	
				
//			"serverPathTrade" : "http://218.22.37.56:8988/servlet/json", // 华安环境   恒生T2
//			"validateimg" : "http://218.22.37.56:8988/servlet/NewImage",
			

			"serverPathTrade" : "http://220.178.81.210:8001/servlet/json", // 华安环境   恒生T2
			"validateimg" : "http://220.178.81.210:8001/servlet/NewImage",
//			"HqUrl" : "http://218.22.37.56:8987/market/json", 	
//            "serverPath":"http://220.178.81.210:8001/servlet/json", // 统一登陆地址
//            "newshareUrl": "http://218.22.37.56:8981/servlet/json",//新股列表
            
//          "serverPathTrade" : "https://zmall.hazq.com:8001/servlet/json", // 华安环境   恒生T2
//			"validateimg" : "https://zmall.hazq.com:8001/servlet/NewImage",
//			"HqUrl" : "http://zmall.hazq.com:8987/market/json",
//			"newshareUrl":"https://zmall.hazq.com:8001/market/json",
            
//			"serverPathTrade" : "http://61.178.68.153:8080/servlet/json", // 华龙证券
//			"validateimg" : "http://61.178.68.153:8080/servlet/NewImage",	
				
//			"serverPathTrade" : "http://zmall.hazq.com:8001/servlet/json", // 华安环境   恒生T2
//			"validateimg" : "http://zmall.hazq.com:8001/servlet/NewImage",
//			"HqUrl" : "http://218.22.37.56:8987/market/json", 
//			"serverPath":"http://220.178.81.210:8001/servlet/json", // 统一登陆地址

//			"serverPathTrade" : "http://61.141.193.114:6001/servlet/json", //世纪   信用91800002 123321
//			"validateimg" : "http://61.141.193.114:6001/servlet/NewImage", // 10014242  123321
//			"HqUrl" : "http://61.144.195.93:6003/market/json",  //世纪小薇行情
					
//			"serverPathTrade" : "http://120.196.127.76:8082/servlet/json", //信达  部署接入网关
//			"validateimg" : "http://120.196.127.76:8082/servlet/NewImage", // 2119003039，123321

			"logoutTimeNum" :"10",//锁定屏幕设置时间，单位分钟
			"hardId": "",
			"activePhone":"",
			"opStationInfo":"思迪信息", 
			"isTrade":true, //是否交易时间
			"tradeList":[
                         {"title" : "新股申购","isShow" :"true","id":"newShare"},
                         {"title" : "融资融券","isShow" : "true","id":"credit"}, 
                         {"title" : "港股通",  "isShow" : "true","id":"ggt"},
                         {"title" : "基金交易","isShow" : "true","id":"fund"}, 
                         {"title" : "OTC交易","isShow" : "false","id":"otc"},
                         {"title" : "其他产品","isShow" : "true","id":"finance"},
                         {"title" : "银证转账","isShow" : "true","id":"banking"},
                         {"title" : "一键归集","isShow" : "true","id":"collection"},
                         {"title" : "修改交易密码","isShow" : "true","id":"changeTradePwd"},
                         {"title" : "修改通讯密码","isShow" : "false","id":"changeMsgPwd"},
                         {"title" : "网络投票","isShow" : "true","id":"voting"},
                         {"title" : "预售要约","isShow" : "false","id":"ysyy"},
                         {"title" : "月月红","isShow" : "false","id":"yyh"}
			            ],
			 "entrust_way" :"5", //委托方式
			 "serverConfig":"2"   //柜台选择   1. 金证win  2. 恒生T2   3. 顶点 （可拓展）
		},
		/**
		 * Android手机返回键处理，退出应用还是返回上级页面，true-退出应用，false-返回页面，默认为true
		 * 如果需要返回上一级页面，并最终提示退出应用，需要改为false，并且在一级页面的html上设置“data-pageLevel="1"”
		 * 不配默认为：true
		 */
		"isDirectExit": true,
		/**
		 * 弹出层各种弹出层主题样式，默认为系统自带
		 * 不配默认为："default"
		 */
		"layerTheme": "d",
		/**
		 * ajax请求超时时间设置，默认为20秒之后超时
		 * 不配默认为：20秒
		 */
		"ajaxTimeout": 30,
		/**
		 * 当弹出等待层时（iLoading），点击遮罩层是否关闭遮罩，关闭后用户可操作页面
		 * 不配默认为：false
		 */
		"isClickShadeHide": false
	};
	
	//暴露对外的接口
	module.exports = window.configuration = configuration;
});