/**
 * 银行产品-产品持仓
 */
define(function(require, exports, module) {
	var appUtils = require("appUtils");
	var common = require("common");
	var gconfig = require("gconfig");
	var global = gconfig.global;
	var layerUtils = require("layerUtils");
	var service_stock = require("service_stock");
	var service_finance = require("service_finance");
	var _pageId = "#finance_bankFinHolding ";
	var VIscroll = require("vIscroll");
	var vIscroll = {"scroll":null,"_init":false}; // 上下滑动
	var userInfo = null;
	var productType = ""; // 产品类型
	var BANKTYPE = "bankProduct"; // 银行产品
	var STOCKTYPE = "stockProduct"; // 证券产品
	
    /**
     * 初始化
     */
	function init() {
		common.bindStockEvent(_pageId); // 绑定头部菜单事件
		productType = appUtils.getSStorageInfo("productType"); // 获取查询产品的类型
		if(productType == BANKTYPE){ // 银行产品
			$(_pageId + ".top_title h3").text("银行产品");
		}else if(productType == STOCKTYPE){ // 证券产品
			$(_pageId + ".top_title h3").text("证券产品");
		}else{
			$(_pageId + ".top_title h3").text("银行产品");
			productType = BANKTYPE;
		}
		userInfo = JSON.parse(appUtils.getSStorageInfo("stock_userInfo")); // 用户信息
		queryData(); // 数据查询
    }
	
	/**
	 * 事件绑定
	 */
	function bindPageEvent() {
		// 返回按钮
		appUtils.bindEvent($(_pageId + ".top_title .icon_back"), function(e){
			pageBack();
		});
		// 银证转账
		appUtils.bindEvent($(_pageId + ".bank_hold .inner a"), function(e){
			appUtils.setSStorageInfo("whichAccount","stock_userInfo");
			appUtils.setSStorageInfo("whichPage","finance/bankFinHolding");
			appUtils.pageInit("finance/bankFinHolding","banking/transfer",{});
		},"click");
	}
	
	/**
	 * 页面数据查询
	 */
	function queryData(){
		queryHolding(); // 查询客户基金持仓
		queryCapital(); // 客户资产查询
	}
	
	/**
	 * 资金账户查询
	 */
	function queryCapital(){
		var entrust_way= global.entrust_way; // 委托方式  在configuration配置
		var branch_no = userInfo.branch_no;	
		var fund_account = userInfo.fund_account;
		var password = userInfo.password;
		var cust_code = userInfo.cust_code; // 关联资产账户标志、
		var money_type = "0"; // 0：人民币，1：美元，2：港币
		var param={				
				"entrust_way":entrust_way,
			    "branch_no":branch_no,
			    "fund_account":fund_account,
			    "password":password,
			    "cust_code":cust_code,
			    "money_type":money_type
		};
		if(productType == BANKTYPE){ // 银行产品
			service_finance.bankFinCapital(param,queryCapitalCallBack);
		}else if(productType == STOCKTYPE){ // 证券产品
			service_finance.stockFinCapital(param,queryCapitalCallBack);
		}
	}
	// 资产查询回调
	function queryCapitalCallBack(data){
		if(data.error_no == 0){
			var results = data.results;
			if(results && results.length>0){
				$(_pageId + ".bank_hold .inner strong").text(common.numToMoneyType(""+results[0].assert_val)); // 总资产(元)
				$(_pageId + ".bank_hold .clearfix li:eq(0) strong").text(common.numToMoneyType(""+results[0].enable_balance)); // 可用资金(元)
				$(_pageId + ".bank_hold .clearfix li:eq(1) strong").text(common.numToMoneyType(""+results[0].fetch_balance)); // 可取资金(元)
				$(_pageId + ".bank_hold .clearfix li:eq(2) strong").text(common.numToMoneyType(""+results[0].current_balance)); // 资金余额(元)
				$(_pageId + ".bank_hold .clearfix li:eq(3) strong").text(common.numToMoneyType(""+results[0].market_val)); // 基金市值(元)
			}
		}else{
			layerUtils.iAlert(data.error_info);
		}
	}
	/**
	 * 产品持仓查询
	 */
	function queryHolding(){
		var entrust_way= global.entrust_way; // 委托方式  在configuration配置
		var branch_no = userInfo.branch_no;	
		var fund_account = userInfo.fund_account;
		var cust_code = userInfo.cust_code;	// 客户代码
		var password = userInfo.password;
		var bankm_account = "";
		var param={				
				"entrust_way":entrust_way,
			    "branch_no":branch_no,
			    "fund_account":fund_account,
			    "password":password,
			    "cust_code":cust_code,
			    "bankm_account":bankm_account
		};
		if(productType == BANKTYPE){ // 银行产品
			service_finance.bankFinShare(param,queryHoldingCallBack);
		}else if(productType == STOCKTYPE){ // 证券产品
			service_finance.stockFinShare(param,queryHoldingCallBack);
		}
	}
    // 产品持仓查询回调
	function queryHoldingCallBack(data){
		if(data.error_no == 0){
			$(_pageId + ".no_data").hide(); 
			$(_pageId + ".fina_list tr:gt(0)").remove();
			var results = data.results;
			if(results && results.length>0){
				var data = "";
				for(var i=0,len=results.length;i<len;i++){
					data += queryHTML(results[i]);
				}
				$(_pageId + ".fina_list tr:eq(0)").after(data);
			}else{
				$(_pageId + ".no_data").show();
			}
			if(!vIscroll._init){
				initVIScroll();
			}else{
				vIscroll.scroll.refresh();
			}
		}else{
			layerUtils.iAlert(data.error_info);
		}
	}
	// 页面数据填充
	function queryHTML(element){
		var price_digit = 2;
		var eleHTML = "";
			eleHTML += "<tr>";     
			eleHTML += "<td><strong>"+element.prod_name+"</strong><small>"+element.prod_code+"</small></td>";
			eleHTML += "<td><span>"+Number(element.enable_amount).toFixed(price_digit)+"</span><span>"+Number(element.current_amount).toFixed(price_digit)+"</span></td>";
			eleHTML += "<td><span class=\"bold\">"+element.buy_date+"</span><span>"+element.allot_no+"</span></td>";
			eleHTML += "</tr>";
		return eleHTML;
	}
	
	/**
	 * 初始化上下滑动组件
	 */
	function initVIScroll(){
		if(!vIscroll._init){
			var config = {
				"isPagingType": false, // false表示是微博那种累加形式，true表示分页形式
				"visibleHeight": $(window).height() - $(_pageId+".top_title").height()- $(_pageId+".tab_nav").height() - 6  ,//显示内容区域的高度，当isPaingType为false时传
				"container": $(_pageId+" #v_container_funds_jj"),	
				"wrapper":$(_pageId+" #v_wrapper_funds_jj"),	
				"downHandle": function() { // 下拉获取上一页数据方法
					queryData();
				},
				"upHandle": function() {
				},
				"wrapperObj": null
			};
			vIscroll.scroll = new VIscroll(config); // 初始化，需要做if(!hIscroll._init)判断
			vIscroll._init = true; // 尽量只初始化一次，保持性能
			
		}else{
			vIscroll.scroll.refresh();
		}
		$(_pageId + ".visc_pullUp").css("display","none");
	}
	
	function destroy(){
	}
	
	/**
	 * 重写框架里面的pageBack方法
	 */
	function pageBack(){
		appUtils.pageInit("finance/bankFinHolding","finance/otherProMain",{});
	}
	
	var base = {
		"init" : init,
		"bindPageEvent": bindPageEvent,
		"destroy": destroy,
		"pageBack": pageBack
	};
	module.exports = base;
});