/**
 * 银行理财-认购
 */
define(function(require, exports, module) {
	var appUtils = require("appUtils");
	var common = require("common");
	var gconfig = require("gconfig");
	var global = gconfig.global;
	var validata = require("validatorUtil");
	var layerUtils = require("layerUtils");
	var service_finance = require("service_finance");
	var service_stock = require("service_stock");
	var service_fund = require("service_fund");
	var _pageId = "#finance_bankFinSubscribe ";
	var productType = ""; // 产品类型
	var BANKTYPE = "bankProduct"; // 银行产品
	var STOCKTYPE = "stockProduct"; // 证券产品
	var userInfo = null;
	var enable_balance = ""; // 可用资金
	var prodta_no = ""; // 产品编号

	/**
	 * 	认购业务流程
	 * 	1， 风险评测 
	 *  2， 判断开户 
	 *  3， 开户 
	 *  4， 产品协议获取(查询产品代码)
	 *  5， 申购/认购 
	 *  6， 开通签署权限 签署 
	 */
    /**
     * 初始化
     */
	function init() {
		var applyType = appUtils.getPageParam("applyType");
		if(applyType == "true"){
			clearMSG();
			layerUtils.iAlert("认购成功！");
		}
		productType = appUtils.getSStorageInfo("productType"); // 获取查询产品的类型
		userInfo = JSON.parse(appUtils.getSStorageInfo("stock_userInfo"));		
		queryCapital(); // 查询可用资金
		window.setTimeout(queryRisk(),200); // 查询风险测评情况
    }
	
	/**
	 * 事件绑定
	 */
	function bindPageEvent() {
		// 返回按钮
		appUtils.bindEvent($(_pageId + ".top_title .icon_back"), function(e){
			pageBack();
		});
		// 产品代码联动
		appUtils.bindEvent($(_pageId + "#proCode"), function(e){
			var proCode = $(this).val();
			if(proCode.length == 6){
				productInfo(proCode); // 产品信息查询
			}else if(proCode.length <6){
				clearMSG(); // 清空信息
			}
		},"keyup");
		// 产品认购
		appUtils.bindEvent($(_pageId + ".ce_btn a"), function(e){
			var prod_code = $(_pageId + "#proCode").val();
			var entrust_balance = $(_pageId + "#totalMoney").val();
			var enable_balance =$(_pageId + ".input_text:eq(4) input").val();
			if(validata.isEmpty(prod_code)){
				layerUtils.iMsg(-1,"产品代码不能为空");
				return false;
			}else if(prod_code.length<6){
				layerUtils.iMsg(-1,"产品代码不能少于6位");
				return false;
			}
			if(validata.isEmpty(entrust_balance) || !entrust_balance>0){
				layerUtils.iMsg(-1,"赎回金额不能小于0");
				return false;
			}else if(Number(entrust_balance)>Number(enable_balance)){
				layerUtils.iMsg(-1,"可用金额不足");
				return false;
			}
			var tipStr ="<div class=\"pop_header\">";
			tipStr+="<h3>"+(productType == BANKTYPE?"银行产品认购":"证券产品认购")+"</h3>";
			tipStr+="</div>";
			tipStr+="<div class=\"pop_main\">";
			tipStr+="<ul>";
		    tipStr+="    <li>产品名称<em>"+$(_pageId+".input_text:eq(1) input").val()+"</em></li>";
		    tipStr+="    <li>产品代码 <strong>"+$(_pageId+"#proCode").val()+"</strong></li>";
			tipStr+="    <li>到期日期 <strong>"+$(_pageId + ".input_text:eq(2) input").val()+"</strong></li>";
			tipStr+="    <li>预计年收益率 <strong>"+$(_pageId + ".input_text:eq(3) input").val()+"</strong></li>";
			tipStr+="    <li>可用资金 <strong>"+enable_balance+"</strong></li>";
			tipStr+="    <li>申购金额 <strong>"+entrust_balance+"</strong></li>";
			tipStr+="</ul>";
			tipStr+="  </div>";
			common.btnConfirm(tipStr,function success(){
				checkData(); // 产品认购
			},function fail(){
			});
			
		});
	}
	
	/**
	 * 	查询风险测评情况
	 */
	function queryRisk(){
		var cust_code = userInfo.cust_code;	// 客户代码
		var fund_account = userInfo.fund_account; // 资产账户
		var branch_no = userInfo.branch_no;	// 分支机构
		var sessionid = userInfo.session_id;
		var entrust_way = global.entrust_way; // 委托方式  在configurat
		var param={			
				"entrust_way":entrust_way,
				"branch_no":branch_no,
				"fund_account":fund_account,
				"cust_code":cust_code,
				"sessionid":sessionid
		};
		if(productType == BANKTYPE){ // 银行产品
			service_finance.bankFinRiskResult(param,queryRiskCallBack);
		}else if(productType == STOCKTYPE){ // 证券产品
			param.risk_kind = "1"; //0 A股 1 基金
			service_finance.stockFinRiskResult(param,queryRiskCallBack);
		}
	}
	function queryRiskCallBack(data){
		if(data.error_no == 0){ 
			var results = data.results;
			if(results && results.length>0){
				var risk_flag = results[0].risk_flag; // 是否过期
                if(risk_flag=="0"){ // 过期
					riskText = "您的风险测评已过期，是否重新测评？";
					var imsg = "<div class=\"pop_header\">";
				    imsg +="<h3 class=\"ared\">风险测评</h3>";
				    imsg +="</div>";
				    imsg +="<div class=\"pop_main\">";
				    imsg +=" <h4>您的风险测评已过期，是否重新测评？<span class=\"ared\"></span></h4>";
				    imsg +="</div>";
					common.btnConfirm(imsg,function(){ // 点击确定
						appUtils.pageInit("finance/bankFinSubscribe","finance/finRiskTest",{});
					},function(){
						pageBack(); // 取消则返回上一页
					});
				}else{
					var prodcode = appUtils.getPageParam("prodcode");
					if(userInfo.client_rights.indexOf("e")<=0){
						stockFinPermission();//开通签署权限
					}
					if(prodcode){
						$(_pageId + "#proCode").val(prodcode);
						productInfo(prodcode); // 产品信息查询
					}
				}
			}
		}else if(data.error_no == "-10"){
			var imsg = "<div class=\"pop_header\">";
		    imsg +="<h3 class=\"ared\">风险测评</h3>";
		    imsg +="</div>";
		    imsg +="<div class=\"pop_main\">";
		    imsg +=" <h4>您暂未进行理财风险测评,请先完成测评再进行交易。是否立即前往测评？<span class=\"ared\"></span></h4>";
		    imsg +="</div>";
		    common.btnConfirm(imsg,function() { // 点击确定
		    	appUtils.pageInit("finance/bankFinSubscribe","finance/finRiskTest",{}); // 跳转到测评页面
			},function(){
				pageBack(); // 取消则返回上一页
			});
		}else{
			layerUtils.iAlert(data.error_info);
		}
	}
	
	/**
	 * 查询可用资金
	 */
	function queryCapital(){
		var entrust_way= global.entrust_way; // 委托方式  在configuration配置
		var branch_no = userInfo.branch_no;	
		var fund_account = userInfo.fund_account;
		var password = userInfo.password;
		var cust_code = userInfo.cust_code; // 关联资产账户标志、
		var money_type = "0"; // 0：人民币，1：美元，2：港币
		var param={				
				"entrust_way":entrust_way,
			    "branch_no":branch_no,
			    "fund_account":fund_account,
			    "password":password,
			    "cust_code":cust_code,
			    "money_type":money_type
		};
//		if(productType == BANKTYPE){ // 银行产品
//			service_finance.bankFinCapital(param,queryCapitalCallBack);
//		}else if(productType == STOCKTYPE){ // 证券产品
//			service_finance.stockFinCapital(param,queryCapitalCallBack);
//		}
		service_stock.queryFundSelect(param,function(data){
			if(data.error_no == 0){
				var results = data.results;
				if(results && results.length>0){
					enable_balance = results[0].enable_balance; // 可用资金(元)
					if($(_pageId + ".input_text:eq(1) input").val()!=""){
						$(_pageId + ".input_text:eq(4) input").val(enable_balance);
					}					
				}
			}else{
				layerUtils.iAlert(data.error_info);
			}
		});
	}
	// 资产查询回调
	function queryCapitalCallBack(data){
		if(data.error_no == 0){
			var results = data.results;
			if(results && results.length>0){
				enable_balance = results[0].enable_balance; // 可用资金(元)
			}
		}else{
			layerUtils.iAlert(data.error_info);
		}
	}
	
	/**
	 * 	签署电子合同
	 */
	function signContract(){
		var cust_code = userInfo.cust_code;	// 客户代码
		var fund_account = userInfo.fund_account; // 资产账户
		var branch_no = userInfo.branch_no;	// 分支机构
		var sessionid = userInfo.session_id;
		var entrust_way = global.entrust_way; // 委托方式  在configurat
		var param={			
				"entrust_way":entrust_way,
				"branch_no":branch_no,
				"fund_account":fund_account,
				"cust_code":cust_code,
				"risk_flag":"a",
				"sessionid":sessionid
		};
		service_fund.signContract(param,function(data){
			if(data.error_no == 0){ // 签署成功继续认购
//				finSubscribe(); // 认购
			}else if(data.error_no == "-30201810"){
				stockFinPermission(); // 没有签署权限，去开通权限
			}
		},{"isLastReq":true,"isShowWait":false,});
	}
	
	/**
	 * 	开通签署权限
	 */
	function stockFinPermission(){
		var cust_code = userInfo.cust_code;	// 客户代码
		var fund_account = userInfo.fund_account; // 资产账户
		var branch_no = userInfo.branch_no;	// 分支机构
		var sessionid = userInfo.session_id;
		var entrust_way = global.entrust_way; // 委托方式  在configurat
		var param={			
				"entrust_way":entrust_way,
				"branch_no":branch_no,
				"fund_account":fund_account,
				"cust_code":cust_code,
				"sessionid":sessionid
		};
		if(productType == BANKTYPE){ // 银行产品
			service_finance.bankFinPermission(param,function(data){
				if(data.error_no == 0){
					signContract(); // 权限开通后再去签署
				}else{
					layerUtils.iAlert(data.error_info);
				}
			},{"isLastReq":true,"isShowWait":false,});
		}else if(productType == STOCKTYPE){ // 证券产品
			service_finance.stockFinPermission(param,function(data){
				if(data.error_no == 0){
					signContract(); // 权限开通后再去签署
				}else{
					layerUtils.iAlert(data.error_info);
				}
			},{"isLastReq":true,"isShowWait":false,});
		}
	}
	
	/**
	 * 	证券理财代码信息查询
	 */
	function productInfo(proCode){
		var cust_code = userInfo.cust_code;	// 客户代码
		var fund_account = userInfo.fund_account; // 资产账户
		var branch_no = userInfo.branch_no;	// 分支机构
		var sessionid = userInfo.session_id;
		var password = userInfo.password;
		var prod_code = proCode;
		var entrust_way = global.entrust_way; // 委托方式  在configurat
		var param={			
				"entrust_way":entrust_way,
				"branch_no":branch_no,
				"fund_account":fund_account,
				"cust_code":cust_code,
				"password":password,
				"prod_code":prod_code,
				"sessionid":sessionid
		};
		if(productType == BANKTYPE){ // 银行产品
			service_finance.bankFinList(param,productInfoCallBack);
		}else if(productType == STOCKTYPE){ // 证券产品
			service_finance.stockFinList(param,productInfoCallBack);
		}
	}
	// 产品信息回调
	function productInfoCallBack(data){
		if(data.error_no == 0){ 
			var results = data.results;
			if(results && results.length>0){
				var prodpre_ratio = results[0].prodpre_ratio; // 预期年化率
				var prod_name = results[0].prod_name; // 产品名
				var prod_term = results[0].prod_term; // 产品期限
				var open_share = results[0].open_share; // 起购金额
				prodta_no = results[0].prodta_no; // 产品编号
				$(_pageId + ".input_text:eq(1) input").val(prod_name);
				$(_pageId + ".input_text:eq(2) input").val(prod_term);
				$(_pageId + ".input_text:eq(3) input").val(prodpre_ratio);
				$(_pageId + ".input_text:eq(4) input").val(enable_balance);
				$(_pageId + "#totalMoney").val(Number(open_share).toFixed(2));
			}else{
				layerUtils.iAlert("暂不存在该产品信息");
			}
		}else{
			layerUtils.iAlert(data.error_info);
		}
	}
	
	/**
	 * 校验可认购
	 */
	function checkData(){
		var entrust_balance = $(_pageId + "#totalMoney").val();
		var cust_code = userInfo.cust_code;	// 客户代码
		var fund_account = userInfo.fund_account; // 资产账户
		var branch_no = userInfo.branch_no;	// 分支机构
		var sessionid = userInfo.session_id;
		var entrust_way = global.entrust_way; // 委托方式  在configurat
		var param={			
				"entrust_way":entrust_way,
				"branch_no":branch_no,
				"fund_account":fund_account,
				"cust_code":cust_code,
				"prodta_no":prodta_no,
				"entrust_balance":entrust_balance,
				"sessionid":sessionid
		};
		if(productType == STOCKTYPE){ // 证券 产品    只有证券产品需要判断是否开户
			service_finance.stockFinIsOpen(param,function(data){
				if(data.error_no == 0){ 
//					finSubscribe(); // 进行认购 
					tipProtocol(STOCKTYPE);
				}else if(data.error_no == -2){ // 未开户
					var param = {"queryNo":prodta_no};
					service_finance.queryProtocol(param,function(data){
						if(data.error_no == 0){
							var results = data.results;
							if(results && results.length>0){
								var imsg = "<div class=\"pop_header\">";
							    imsg +="<h3 class=\"ared\">开户</h3>";
							    imsg +="</div>";
							    imsg +="<div class=\"pop_main\">";
							    imsg +=" <h4>您暂未开户,请先完成开户再进行交易。是否立即前往开户？<span class=\"ared\"></span></h4>";
							    imsg +="</div>";
							    common.btnConfirm(imsg,function() { // 点击确定
							    	var params = {
							    			"type":"openStock",
							    			"prodta_no":prodta_no
							    	};
							    	appUtils.pageInit("finance/bankFinApply","finance/signProtocol",{"productInfo":params});
								},function(){
									return false; // 取消则返回上一页
								});
								
							}else{
								stockFinOpen(); // 前往开户
							}						
						}
					},{"isLastReq":true,"isShowWait":false,});
//					stockFinOpen(); // 前往开户
				}else if(data.error_no == -10){
					stockFinPermission();
				}else{
					layerUtils.iAlert(data.error_info);
				}
			});
		}else{
			service_finance.bankFinIsOpen(param,function(data){
				if(data.error_no == 0){ 
					finSubscribe(); // 进行认购 
				}else{
					layerUtils.iAlert(data.error_info);
				}
			});
		}
	}
	
	/**
	 * 产品认购方法
	 */
	function finSubscribe(){
		var prod_code = $(_pageId + "#proCode").val();
		var entrust_balance = $(_pageId + "#totalMoney").val();
		var cust_code = userInfo.cust_code;	// 客户代码
		var fund_account = userInfo.fund_account; // 资产账户
		var branch_no = userInfo.branch_no;	// 分支机构
		var sessionid = userInfo.session_id;
		var entrust_way = global.entrust_way; // 委托方式  在configurat
		var param={			
				"entrust_way":entrust_way,
				"branch_no":branch_no,
				"fund_account":fund_account,
				"cust_code":cust_code,
				"prod_code":prod_code,
				"prodta_no":prodta_no,
				"entrust_balance":entrust_balance,
				"sessionid":sessionid
		};
		if(productType == BANKTYPE){ // 银行产品
			service_finance.bankFinSubscribe(param,finSubscribeCallBack);
		}else if(productType == STOCKTYPE){ // 证券产品
			service_finance.stockFinSubscribe(param,finSubscribeCallBack);
		}
	}
	// 产品认购回调
	function finSubscribeCallBack(data){
		if(data.error_no == 0){
			var results = data.results;
			if(results && results.length>0){
				layerUtils.iAlert("产品认购成功");
			}
		}else if(data.error_no == "-30180210"){
			signContract(); // 签署电子合同
		}else{
			layerUtils.iAlert(data.error_info);
		}
	}
	
	/**
	 * 证券产品开户
	 */
	function stockFinOpen(){
		var cust_code = userInfo.cust_code;	// 客户代码
		var fund_account = userInfo.fund_account; // 资产账户
		var branch_no = userInfo.branch_no;	// 分支机构
		var sessionid = userInfo.session_id;
		var entrust_way = global.entrust_way; // 委托方式  在configurat
		var param={			
				"entrust_way":entrust_way,
				"branch_no":branch_no,
				"fund_account":fund_account,
				"cust_code":cust_code,
				"prod_code":prod_code,
				"prodta_no":prodta_no,
				"sessionid":sessionid
		};
		service_finance.stockFinOpen(param,function(data){
			if(data.error_no == 0){
				var results = data.results;
				if(results && results.length>0){
					appUtils.pageInit("finance/bankFinSubscribe","finance/signProtocol",{});
				}
			}else{
				layerUtils.iAlert(data.error_info);
			}
		});
	}
	
	//提示签署协议
	function tipProtocol(){
		var prod_code = $(_pageId + "#proCode").val();
		var entrust_balance = $(_pageId + "#totalMoney").val();
		var params = {"queryNo":prod_code};
		service_finance.queryProtocol(params,function(data){
			if(data.error_no == 0){
				var results = data.results;
				if(results && results.length>0){
					if(productType == BANKTYPE){ // 银行产品
						p_type = "bankFinSubscribe";
					}else if(productType == STOCKTYPE){ // 证券产品
						p_type = "stockFinSubscribe";
					}
					var param = {
							"p_type":p_type,
							"type":"product",
							"prod_code":prod_code,
							"prodta_no":prodta_no,
							"entrust_balance":entrust_balance
					};
					appUtils.pageInit("finance/bankFinSubscribe","finance/signProtocol",{"productInfo":param});
				}else{
					finSubscribe();
				}
			}else{
				layerUtils.iAlert(data.error_info);
			}
		});
	}
	
	/**
	 * 清除数据
	 */
	function clearMSG(){
		$(_pageId + "#totalMoney").val("");
		$(_pageId + ".input_text:eq(1) input").val("");
		$(_pageId + ".input_text:eq(2) input").val("");
		$(_pageId + ".input_text:eq(3) input").val("");
		$(_pageId + ".input_text:eq(4) input").val("");
	}
	
	function destroy(){
		
		var prePage = appUtils.getSStorageInfo("_prePageCode");
		if(prePage !="finace/signProtocol"){
			$(_pageId + "#proCode").val("");
			clearMSG();
		}
	}
	
	/**
	 * 重写框架里面的pageBack方法
	 */
	function pageBack(){
		$(_pageId + "#proCode").val("");
		clearMSG();
		appUtils.pageInit("finance/bankFinSubscribe","finance/bankFinOrder",{});
	}
	
	var base = {
		"init" : init,
		"bindPageEvent": bindPageEvent,
		"destroy": destroy,
		"pageBack": pageBack
	};
	module.exports = base;
});