/**
 * 基金交易-申购
 */
define(function(require, exports, module) {
	var appUtils = require("appUtils");
	var layerUtils = require("layerUtils");
	var gconfig = require("gconfig");
	var global = gconfig.global;
	var common = require("common");
	var external = require("external");
	var validata = require("validatorUtil");
	var service_fund = require("service_fund");
	var service_stock = require("service_stock");
    var _pageId = "#fund_fundApply ";
    var userInfo = null;
    
    /**
     * 初始化
     */
	function init(){
		common.systemKeybord(); // 解禁系统键盘
		common.bindStockEvent(_pageId); //绑定头部菜单事件
		userInfo = JSON.parse(appUtils.getSStorageInfo("stock_userInfo"));
		queryCapital(); // 查询可用资金
		queryRiskTest(); // 查询风险测评
		if(gconfig.platform=="0"){ //方便pc端调试
			$(_pageId+"#fundCode").attr("readonly",false);
		}	
    }
	
	/**
	 * 事件绑定
	 */
	function bindPageEvent(){
		//返回按钮
		appUtils.bindEvent($(_pageId + ".top_title .icon_back"), function(e){
			appUtils.pageInit("fund/fundApply","account/index",{});
		});
		//股票代码输入框监听
		appUtils.bindEvent($(_pageId+"#fundCode"), function(e){
			var fundCode = $(this).val();
			if(fundCode.length == 6){
				getFundList(fundCode);
			}else if(fundCode.length > 6){
				$(this).val(fundCode.substring(0,6));
			}else if(fundCode.length < 6){
				clearBuyMsg();
			}
			$(_pageId+".trade_form .input_box .stat").hide();
			e.stopPropagation();
		},"keyup");
		
		//股票代码输入框调用原生键盘
		appUtils.bindEvent($(_pageId+"#fundCode"),function(e){
			window.customKeyboardEvent = {
				keyBoardFinishFunction: function(){},
				keyBoardInputFunction: function(){
					var fundCode = $(_pageId+"#fundCode").val();
					if(fundCode.length == 6){
						getFundList(fundCode);
					}else if(fundCode.length > 6){
						$(this).val(fundCode.substring(0,6));
					}else if(fundCode.length < 6){
						clearBuyMsg();
					}
					$(_pageId+".trade_form .input_box .stat").hide();
				}
			};
			external.callMessage({"moduleName":"trade","funcNo": "50210", "pageId":"fund_fundApply", "eleId":"fundCode", "doneLable":"done", "keyboardType":"2"});
			e.stopPropagation();
		},"click");
		//失去焦点关闭原生键盘
		appUtils.bindEvent($(_pageId+"#fundCode"),function(e){
			external.callMessage({"moduleName":"trade","funcNo": "50211"});
			e.stopPropagation();
		},"blur");
		
		//申购
		appUtils.bindEvent($(_pageId + ".input_form .ce_btn"), function(e){
			var flag = "";
			vailSubmitOrder(flag);
			e.stopPropagation();
		});
	}
    
	/**
	 * 获取基金列表
	 * */
	function getFundList(fundStr){
		if(fundStr!= "" && fundStr.length==6){
			$(_pageId+"#fundName").val("");
			$(_pageId+"#fundNav").val("");
			var entrust_way= global.entrust_way; // 委托方式  在configuration配置
			var fund_code = fundStr;
			var fund_company="";
			var branch_no = userInfo.branch_no;	
			var fund_account = userInfo.fund_account;
			var cust_code = userInfo.cust_code;//关联资产账户标志
			var password = userInfo.password;
			var param={				
					"entrust_way":entrust_way,
				    "branch_no":branch_no,
				    "fund_account":fund_account,
				    "cust_code":cust_code,
				    "password":password,
					"fund_company":fund_company,
					"fund_code":fund_code
			};
			service_fund.getFundInfo(param,getFundInfoBack);
		}	
	}
	function getFundInfoBack(data){
		if(data.error_no == 0){
			var results = data.results;
			if(results && results.length > 0){
				var nav=results[0].nav!=""?results[0].nav:"0";
				var fundCompany = results[0].fund_company;
				 $(_pageId+"#fundName").find("span").text(results[0].fund_name);
                 $(_pageId+"#fundName").find("span").attr("data-fundCom",fundCompany);
				 $(_pageId+"#fundNav").val(Number(nav)+"元");
			}
			else{
				layerUtils.iAlert("没有查询到对应的基金");
			}
		}else{
			layerUtils.iAlert(data.error_info);
		}
	}
	
	/**
	 * 资金账户查询
	 */
	function queryCapital(){
		//获取保存在本地的账户信息
		var entrust_way= global.entrust_way; // 委托方式  在configuration配置
		var branch_no = userInfo.branch_no;	
		var fund_account = userInfo.fund_account;
		var cust_code = userInfo.cust_code;//关联资产账户标志
		var password = userInfo.password;
		var money_type = "0";  //  0：人民币，1：美元，2：港币
		var param={				
				"entrust_way":entrust_way,
			    "branch_no":branch_no,
			    "fund_account":fund_account,
			    "cust_code":cust_code,
			    "money_type":money_type,
			    "password":password
		};
		//最后一个为超时处理函数
		service_stock.queryFundSelect(param,queryCapitalCallback);
	}
	
	/**
	 * 资金账户查询回调
	 */
	function queryCapitalCallback(data){
		if (data && data!= "undefined"){
			if(data.error_no == 0){
				var results = data.results;
				if(results[0] && results!= "undefined"){
					$(_pageId+".input_form .max strong").text(common.numToMoneyType(""+Number(results[0].enable_balance).toFixed(2)+""));//可用
				}else{
					$(_pageId+".input_form .max strong").text("--");//可用
				}
			}else{
				layerUtils.iAlert(data.error_info);
			}
		}
	}
	
	/**
	 * 下单验证
	 * */
	function vailSubmitOrder(flag){
		//验证基金代码输入是否正确
		var buy_stockCode = $(_pageId+"#fundCode").val().substring(0,6);
		if(buy_stockCode.length == 0){
			layerUtils.iMsg(-1,"请输入基金代码");
			return false;
		}	
		if(buy_stockCode.length <5){
			layerUtils.iMsg(-1,"基金代码输入错误");
			return false;
		}	
		//验证基金份额输入是否正确
		var now_price = $(_pageId+"#fundPrice").val();
		var can_buy = $(_pageId+".input_form .max strong").text();
		if($.trim(now_price).length<=0){
			layerUtils.iMsg(-1,"请输入申购金额");
			return false;
		}else if(now_price=="0"){
			layerUtils.iMsg(-1,"申购金额不能为0");
			return false;
		}else if(!validata.isNumberFloat(now_price)||parseFloat(now_price)<0){
			layerUtils.iMsg(-1,"请正确输入申购金额");
			return false;
		}else if(Number(now_price)>Number(can_buy)){
			layerUtils.iMsg(-1,"申购金额超过可用金额");
			return false;
		}
		var tipStr ="<div class=\"pop_header\">";
		tipStr+="<h3>基金申购</h3>";
		tipStr+="</div>";
		tipStr+="<div class=\"pop_main\">";
		tipStr+="<ul>";
		tipStr+="    <li>基金名称 <em>"+ $(_pageId+" #fundName").find("span").text()+"</em></li>";
		tipStr+="    <li>基金代码 <strong>"+buy_stockCode+"</strong></li>";
		tipStr+="    <li>申购金额 <strong>"+now_price+"</strong></li>";
		tipStr+="</ul>";
		tipStr+="  </div>";
		common.btnConfirm(tipStr,function success(){
		var cust_code = userInfo.cust_code;	//客户代码
		var fund_account = userInfo.fund_account;	//资产账户
		var branch_no  = userInfo.branch_no;	//分支机构
		var sessionid=userInfo.sessionid;
		var entrust_way= global.entrust_way; // 委托方式  在configuration配置
		var password= userInfo.password;
		var fund_company=$(_pageId+"#fundName").find("span").attr("data-fundCom");
		var fund_code = buy_stockCode;
		var balance = now_price;
        var charge_type = $(_pageId + " #fundCode").attr("data-chargeType"); //收费方式
		var param = {
				"entrust_way":entrust_way,
				"branch_no":branch_no,
				"fund_account":fund_account,
				"cust_code":cust_code,
				"password":password,
				"sessionid":sessionid,
				"fund_company":fund_company,
				"fund_code":fund_code,
				"flag":flag,
				"balance":balance,
	            "charge_type":charge_type
			};
		    service_fund.getpurchaseBuy(param,getBuyCallBack);
		},function fail(){
		} );
	}
	//申购回调
	function getBuyCallBack(data){
		if(data.error_no == 0){
			var results = data.results;
			if(results){
				$(_pageId+"#fundPrice").val("");
				layerUtils.iAlert(data.error_info);
				queryCapital();
			}
		}else if(data.error_no == "-30200710") {   //未开户时
			var imsg = "<div class=\"pop_header\">";
			    imsg +="<h3 class=\"ared\">基金开户</h3>";
			    imsg +="</div>";
			    imsg +="<div class=\"pop_main\">";
			    imsg +=" <h4>该基金您暂未开通权限，您是否现在开通？<span class=\"ared\"></span></h4>";
			    imsg +="</div>";
			common.btnConfirm(imsg,function() { // 点击确定
				var param = {
						"entrust_way" : global.entrust_way, // 委托方式  在configuration配置
						"branch_no" : userInfo.branch_no, // 分支机构
						"fund_account" : userInfo.fund_account, //资产账户
						"cust_code" : userInfo.cust_code, //客户代码
						"password" : userInfo.password, // 交易密码
						"sessionid" : userInfo.sessionid, // 会话号
						"fund_company" : $(_pageId+"#fundName").find("span").attr("data-fundCom") // 基金公司代码
				};
				// 基金开户
				service_fund.fundOpenAccount(param, function(data){
					if(data.error_no == 0) {
						layerUtils.iAlert("基金户开通成功");
						//vailSubmitOrder();
					} else {
						layerUtils.iAlert(data.error_info);
					}
				});
			});
		}else if(data.error_no == "-30200711"){
			var imsg = "<div class=\"pop_header\">";
		    imsg +="<h3 class=\"ared\">强制下单</h3>";
		    imsg +="</div>";
		    imsg +="<div class=\"pop_main\">";
		    imsg +=" <h4>"+data.error_info+"<span class=\"ared\"></span></h4>";
		    imsg +="</div>";
		    common.btnConfirm(imsg,function() { // 点击确定
		    	var flag = "1";
		    	vailSubmitOrder(flag);
			});
		}else{
			layerUtils.iAlert(data.error_info);
		}
	}
	
	/**
	 * 查询风险测评状态 
	 */
	function queryRiskTest(){
		//获取保存在本地的账户信息
		var userInfo = JSON.parse(appUtils.getSStorageInfo("stock_userInfo"));
		var entrust_way= global.entrust_way; // 委托方式  在configuration配置
		var branch_no = userInfo.branch_no;	
		var fund_account = userInfo.fund_account;
		var password = userInfo.password;
		var cust_code = userInfo.cust_code;//关联资产账户标志
		var risk_kind = "1";//0 A股 1 基金
		var param={				
				"entrust_way":entrust_way,
			    "branch_no":branch_no,
			    "fund_account":fund_account,
			    "cust_code":cust_code,
			    "password":password,
			    "risk_kind":risk_kind,
		};
		service_fund.riskLevelQuery(param,function(data){
			if(data.error_no == "0"){
				var result = data.results[0];
				if(result){
					var risk_flag = result.risk_flag;
					if(risk_flag == "0"){
						layerUtils.iAlert("您的风险测评已过期，请重新测评");
					}
				}
			}else if(data.error_no == "-10"){
				var imsg = "<div class=\"pop_header\">";
			    imsg +="<h3 class=\"ared\">风险测评</h3>";
			    imsg +="</div>";
			    imsg +="<div class=\"pop_main\">";
			    imsg +=" <h4>您暂未进行基金风险测评,请先完成测评再进行基金交易。是否立即前往测评？<span class=\"ared\"></span></h4>";
			    imsg +="</div>";
			    common.btnConfirm(imsg,function() { // 点击确定
			    	appUtils.pageInit("fund/fundApply","fund/assessmentRisk",{}); // 跳转到测评页面
				},function(){
					appUtils.pageInit("fund/fundApply","account/index",{}); // 取消直接返回首页
				});
			}else{
				layerUtils.iAlert(data.error_info);
				return false;
			}
		});
	}
	
	/**
	 * 重置页面数据  
	 */
	function clearBuyMsg(){
		$(_pageId+"#fundPrice").val("");
		$(_pageId+"#fundNav").val("");
		$(_pageId+"#fundName").find("span").text("");
	}
	/**
	 * 销毁
	 */
	function destroy(){
		clearBuyMsg();
		$(_pageId+"#fundCode").val("");
		external.callMessage({"moduleName":"trade","funcNo": "50211"});
		$(_pageId+".input_form .max strong").text("--");//可用
		
	}

	/**
	 * 重写框架里面的pageBack方法
	 */
	function pageBack(){
		appUtils.pageInit("fund/fundApply","account/index",{});
	}
	
	var base = {
		"init" : init,
		"bindPageEvent": bindPageEvent,
		"destroy": destroy,
		"pageBack": pageBack
	};
	module.exports = base;
});