/**
 * 网络投票service层调用接口
 */
define(function(require, exports, module) {

	var gconfig = require("gconfig");
	var appUtils = require("appUtils");
	var service = require("service");
	var global = gconfig.global;
	var serviceSingleton = new service.Service();
    
	/********************************公共代码部分********************************/
    function commonInvoke(paraMap, callback, ctrlParam, reqParamVo){
		reqParamVo.setReqParam(paraMap);
		ctrlParam = ctrlParam?ctrlParam:{};
		reqParamVo.setIsLastReq(ctrlParam.isLastReq);
		reqParamVo.setIsAsync(ctrlParam.isAsync);
		reqParamVo.setIsShowWait(ctrlParam.isShowWait);
		reqParamVo.setTimeOutFunc(ctrlParam.timeOutFunc);
		reqParamVo.setIsShowOverLay(ctrlParam.isShowOverLay);
		reqParamVo.setTipsWords(ctrlParam.tipsWords);
		reqParamVo.setDataType(ctrlParam.dataType);
		reqParamVo.setIsGlobal(ctrlParam.isGlobal);
		reqParamVo.setProtocol(ctrlParam.protocol);
		serviceSingleton.invoke(reqParamVo, callback);
	}

	function destroy(){
		serviceSingleton.destroy();
	}
	var service_added = { //对应的接口方法需要在这里暴露出来
		"getInstance": getInstance, //为了避免以前调用getInstance方法报错
		"destroy": destroy
	};
	function getInstance(){
		return service_added;
	}
	module.exports = service_added;
	
	/********************************应用接口开始********************************/

	/**
	 * 添加OpStation
	 * */
	function addOpStation(param){
		var channelNo = " "; // 通道编号
		var ipAddr = " "; // ip 
		var macAddr = " "; // mac
		var hardId = " "; // 硬盘序列号（硬件id）
		var cpuId = " "; // cpu 序列号
		var mobileNo = " "; // 手机号
		var hardIdentifier = " "; //硬件特征码
		var source = " "; // 来源
		var other = " "; // 其他
 
		if(iBrowser.android){
			channelNo = "1";
		}else if(iBrowser.iPad || iBrowser.iPhone || iBrowser.ios){
			channelNo = "2";
		}else if(iBrowser.pc){
			channelNo = "0";
		}
		if(gconfig.platform != "0"){
			var external = require("external");
			var mobileNoInfo = external.callMessage({"funcNo":"50043","key":"mobilePhone"}); // 电话号码
			if(mobileNoInfo.error_no == "0" && mobileNoInfo.results[0].value!=""){
				mobileNo = mobileNoInfo.results[0].value;
			}
			var hardIdInfo = external.callMessage({"funcNo": "50022"}); //设备唯一码
			if(hardIdInfo.error_no ==  "0" && hardIdInfo.results[0].deviceToken!=""){
				hardId = hardIdInfo.results[0].deviceToken;
			}
			var ipAddrInfo = external.callMessage({"funcNo": "50023"}); //设备IP地址
			if(ipAddrInfo.error_no ==  "0" && ipAddrInfo.results[0].ip!=""){
				ipAddr = ipAddrInfo.results[0].ip;	
			}
			var macAddrInfo = external.callMessage({"funcNo": "50024"}); //设备MAC地址 
			if(macAddrInfo.error_no ==  "0" && macAddrInfo.results[0].mac!=""){
				macAddr = macAddrInfo.results[0].mac;
			}
			var versionInfo = external.callMessage({"funcNo": "50010"}); //应用版本号
			if(versionInfo.error_no ==  "0" && versionInfo.results[0].version!=""){
				other = versionInfo.results[0].version;
			}
		}
		source = global.opStationInfo; //来源
		var aOpStation = [];
		aOpStation.push(channelNo);
		aOpStation.push("|");
		aOpStation.push(ipAddr);
		aOpStation.push("|");
		aOpStation.push(macAddr);
		aOpStation.push("|");
		aOpStation.push(hardId);
		aOpStation.push("|");
		aOpStation.push(cpuId);
		aOpStation.push("|");
		aOpStation.push(mobileNo);
		aOpStation.push("|");
		aOpStation.push(hardIdentifier);
		aOpStation.push("|");
		aOpStation.push(source);
		aOpStation.push("|");
		aOpStation.push(other);
//		console.log(aOpStation.join(""));
		param.op_station = aOpStation.join(""); // 通道编号|IP地址|MAC地址|硬盘序列号|CPU序列号|手机号码|硬件特征码|来源|其他
	}
	/********************************业务范围--网络投票等功能********************************/
	
	/**
	 * 股东大会信息查询
	 * @param {Object} entrust_way				委托方式
	 * @param {Object} branch_no				分支机构
	 * @param {Object} fund_account				资金账号
	 * @param {Object} cust_code				客户编号	
	 * @param {Object} password					交易密码
	 * @param {Object} op_station				操作站点	
	 * @param {Object} sessionid				会话号
	 * @param {Object} exchange_type			市场
	 * @param {Object} company_code				公司代码
	 * @param {Object} vote_code				产品代码
	 * */
	service_added.queryStockMeetingInfo = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "301530";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["exchange_type"] = param.exchange_type;
		paraMap["company_code"] = param.company_code;
		paraMap["vote_code"] = param.vote_code;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
 		reqParamVo.setUrl( global.serverPathTrade);
 		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 投票议案信息查询
	 * @param {Object} entrust_way				委托方式
	 * @param {Object} branch_no				分支机构
	 * @param {Object} fund_account				资金账号
	 * @param {Object} cust_code				客户编号	
	 * @param {Object} password					交易密码
	 * @param {Object} op_station				操作站点	
	 * @param {Object} sessionid				会话号
	 * @param {Object} meeting_seq				股东大会编码
	 * @param {Object} v_id						议案编号
	 * @param {Object} vote_code				产品代码
	 * */
	service_added.queryVoteBillInfo = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "301531";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["sessionid"] = param.sessionid;
		paraMap["meeting_seq"] = param.meeting_seq;
		paraMap["v_id"] = param.v_id;
		paraMap["vote_code"] = param.vote_code;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
 		reqParamVo.setUrl( global.serverPathTrade);
 		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	
	/**
	 * 上交所网络投票
	 * @param {Object} entrust_way				委托方式
	 * @param {Object} branch_no				分支机构
	 * @param {Object} fund_account				资金账号
	 * @param {Object} cust_code				客户编号	
	 * @param {Object} password					交易密码	
	 * @param {Object} op_station				操作站点	
	 * @param {Object} exchange_type			市场	
	 * @param {Object} stock_account			证券代码	
	 * @param {Object} stock_code				股东代码
	 * @param {Object} sessionid				会话号
	 * @param {Object} meeting_seq				股东大会编码
	 * @param {Object} v_id						议案编号
	 * @param {Object} vote_number				投票数量
	 * @param {Object} vote_result				投票意见
	 * @param {Object} order_group				委托批号
	 * */
	service_added.queryVote = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "301533";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["exchange_type"] = param.exchange_type;
		paraMap["stock_account"] = param.stock_account;
		paraMap["stock_code"] = param.stock_code;
		paraMap["sessionid"] = param.sessionid;
		paraMap["meeting_seq"] = param.meeting_seq;
		paraMap["flag"] = param.flag;
		paraMap["v_id"] = param.v_id;
		paraMap["vote_number"] = param.vote_number;
		paraMap["vote_result"] = param.vote_result;
		paraMap["order_group"] = param.order_group;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
 		reqParamVo.setUrl( global.serverPathTrade);
 		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};
	
	/**
	 * 网络投票委托查询
	 * @param {Object} entrust_way				委托方式
	 * @param {Object} branch_no				分支机构
	 * @param {Object} fund_account				资金账号
	 * @param {Object} cust_code				客户编号	
	 * @param {Object} password					交易密码	
	 * @param {Object} op_station				操作站点	
	 * @param {Object} exchange_type			市场	
	 * @param {Object} stock_account			证券代码	
	 * @param {Object} stock_code				股东代码
	 * @param {Object} sessionid				会话号
	 * @param {Object} meeting_seq				股东大会编码
	 * @param {Object} v_id						议案编号
	 * @param {Object} vote_number				投票数量
	 * @param {Object} vote_result				投票意见
	 * @param {Object} order_group				委托批号
	 * */
	service_added.queryVoteHistory = function(param,callback,ctrlParam){
		var paraMap = {};
		paraMap["funcNo"] = "301534";
		paraMap["entrust_way"] = param.entrust_way;
		paraMap["branch_no"] = param.branch_no;
		paraMap["fund_account"] = param.fund_account;
		paraMap["cust_code"] = param.cust_code;
		paraMap["password"] = param.password;
		paraMap["exchange_type"] = param.exchange_type;
		paraMap["stock_account"] = param.stock_account;
		paraMap["stock_code"] = param.stock_code;
		paraMap["sessionid"] = param.sessionid;
		paraMap["meeting_seq"] = param.meeting_seq;
		paraMap["v_id"] = param.v_id;
		paraMap["begin_date"] = param.begin_date;
		paraMap["end_date"] = param.end_date;
		addOpStation(paraMap); // 添加 op_station 到接口请求参数中
		var reqParamVo = new service.ReqParamVo();
 		reqParamVo.setUrl( global.serverPathTrade);
 		commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
	};

	/***应用接口......................................................结束*/

});