/**
 * 个人中心页面
 */
define(function(require, exports, module){
	/*模块内部全局变量*/
	var appUtils = require("appUtils"),
		layerUtils = require("layerUtils"),
		utils = require("utils"),
		userInfoInSession = null,  // session 中的 userInfo
		service = require("mobileService_xdt"),  //业务层接口，请求数据
		_pageId = "#account_myAssetsDebt";
	
	/*页面初始化方法*/
	function init()
	{
		userInfoInSession = utils.getUserInfoInSession();
		queryStockValue();  // 查询总资产
	}
	
	/*绑定页面事件的方法*/
	function bindPageEvent()
	{
		/*进入首页*/
		appUtils.bindEvent($(_pageId+" header .icon_back"), function(e){
			$(this).addClass("active");
			e.stopPropagation();
		},"touchstart");
		/*进入首页*/
		appUtils.bindEvent($(_pageId+" header .icon_back"), function(e){
			$(this).removeClass("active");
			appUtils.pageInit("account/myAssetsDebt", "business/appIndex");
			e.stopPropagation();
		},"touchend");
	}
	
	/*页面销毁方法*/
	function destroy()
	{
		service.destroy();
		$(_pageId+" .no_data").hide();  // 隐藏暂无数据
	}
	
	/*查询总资产*/
	function queryStockValue()
	{
		var queryStockValueparam = {
				custid : userInfoInSession.custid,  // 客户 id
				fundid : userInfoInSession.fundid  // 资金账号
		};
		service.queryStockValue(queryStockValueparam,function(data){
			if(data.error_no=="0")
			{
				fillAssetsData(data.results); // 填充总资产
				queryStockList();  // 查询股东账户列表
			}
			else
			{
				layerUtils.iLoading(false);
				layerUtils.iAlert(data.error_info);	
			}
			
		}, {"isLastReq":false});
	}
	
	/*填充总资产数据*/
	function fillAssetsData(results)
	{
		$(_pageId+" #fundbal").html(results[0].fundbal); // 资金余额
		$(_pageId+" #fundavl").html(results[0].fundavl); // 可用资金
		$(_pageId+" #stkvalue").html(results[0].stkvalue); // 可取资金
		$(_pageId+" #marketvalue").html(results[0].marketvalue); //总资产
	}
	
	/*查询股东账户列表*/
	function queryStockList()
	{
		var queryStockListparam = {
				custid : userInfoInSession.custid,  // 客户 id
				fundid : userInfoInSession.fundid,  // 资金账号
				orgid : userInfoInSession.orgid   // 机构ID
		};
		service.queryStockList(queryStockListparam,function(data){
			if(data.error_no == "0")
			{
				if(data.results.length != 0)
				{
					fillStockList(data.results);  // 填充股票列表
				}
				else
				{
					$(_pageId+" .no_data").show();  // 显示暂无数据
				}
			}
			else
			{
				layerUtils.iAlert(data.error_info);	
			}
			
		});
	}
	
	/**
	 * 填充股票列表
	 * @param results 查询出来的股票结果集
	 */
	function fillStockList(results)
	{
		var allStockStr = "";  // 所有股票的字符串
		for(var i = 0; i < results.length; i++)
		{
			var oneData = results[i],  // 一条数据
				stkname = oneData.stkname,  // 股票名称
				stkcode = oneData.stkcode,  // 股票代码
	            stkqty = oneData.stkqty,  // 股票数量
	            stkavl = oneData.stkavl,  // 可质押数量
	            secuid = oneData.secuid;  // 股东账号
			allStockStr += '<tr>';
			allStockStr += '<td>'+stkname+'</td>';
			allStockStr += '<td>'+stkcode+'</td>';
			allStockStr += '<td>'+stkqty+'</td>';
			allStockStr += '<td>'+stkavl+'</td>';
			allStockStr += '<td>'+secuid+'</td>';
			allStockStr += '</tr>';
		}
		var th = $(_pageId+" #stockList tr:eq(0)");  // 表头
		$(_pageId+" #stockList").html(th).append(allStockStr);  // 设置表头之后填充股票列表
	}
	
	/*向外暴露的 JSON 对象*/
	var myAssetsDebt = {
			"init" : init,
			"bindPageEvent" : bindPageEvent,
			"destroy" : destroy
	};
	
	/*对外暴露 JSON 对象*/
	module.exports = myAssetsDebt;
});