/**
 * 风险测评页面
 */
define(function(require, exports, module){
	/*模块内部全局变量*/
	var appUtils = require("appUtils"),
		layerUtils = require("layerUtils"),
		utils = require("utils"),
		gconfig = require("gconfig"),
		global = gconfig.global,
		service = require("mobileService_xdt"),  //业务层接口，请求数据
		allQuesArray = null,  // 所有风险测评数组
		subid = "34",  // 题库 id
		isFirstLand = "",
	     prepageCode = "",
		_pageId = "#apply_riskAssessment";
	
	/*页面初始化方法*/
	function init()
	{
		allQuesArray = [];
		var pageParam = appUtils.getPageParam();
		prepageCode = appUtils.getSStorageInfo("_prePageCode");
		$(_pageId+" .assessment").height(($(document).height()-178)+"px");
		queryRiskQuestions();  // 查询风险测评题目
	}
	
	/*绑定页面事件的方法*/
	function bindPageEvent()
	{
		/*返回*/
		appUtils.bindEvent($(_pageId+" .xdt"), function(e){
			$(this).addClass("active");
			e.stopPropagation();
		},"touchstart");
		/*返回*/
		appUtils.bindEvent($(_pageId+" .xdt"), function(e){
			$(this).removeClass("active");
			appUtils.pageBack();
			e.stopPropagation();
		},"touchend");
		/*确定按钮*/
		appUtils.bindEvent($(_pageId+" #nextStep"), function(e){
			if(validateNext())  // 校验下一步条件
			{
				postRiskAnswer();  // 提交风险测评答案
			}
			e.stopPropagation();
		});
		/*取消按钮*/
		appUtils.bindEvent($(_pageId+" #toIndex"), function(e){
			 appUtils.pageInit("apply/riskAssessment","business/borrowIndex");
			e.stopPropagation();
		});
	}
	
	/*页面销毁方法*/
	function destroy()
	{
		service.destroy();
	}
	
	/*校验下一步条件*/
	function validateNext()
	{
		var bAllChoose = true,  // boolean 类型的变量，题目是否全部答完
			aNoSelQuesNo = [];  // array 类型的变量，没有选择的问题编号数组
		$(_pageId+" #test_main li").each(function(index, obj){
			if($(this).find(".cont span[class='on']").attr("ans-id")==undefined)
			{
				bAllChoose = false;
				aNoSelQuesNo.push(index+1);
			}
		});
		if(!bAllChoose)  // 当有题未选择答案时
		{
			layerUtils.iMsg(-1, "您还有【"+aNoSelQuesNo.join("、")+"】未完成");
		}
		return bAllChoose;
	}
	
	/*提交风险测评答案*/
	function postRiskAnswer()
	{
		layerUtils.iLoading(true);
		var riskAnswerParam = {
			 "sub_id" : subid,
			 "answer_result" : getRiskAnswer()  // 获取风险测评答案
		};
		service.postAnswers(riskAnswerParam,function(data){
			if(data.error_no == 0){
				utils.addDataToUserInfo("risk_level", data.results[0].define);  // 保存测评结果
				utils.addDataToUserInfo("valid_flag",1);
				if(prepageCode == "apply/lastRiskResult"){
					appUtils.pageInit("apply/riskAssessment","apply/lastRiskResult");
				}
				else{
					appUtils.pageInit("apply/riskAssessment","apply/riskResult");
				}
				
			}
			else{
				layerUtils.iAlert(data.error_info);
			}
		});
		
	}
	
	/**
	 * 获取风险测评答案
	 * 返回的数据格式：34|58|144&34|57|139&34|56|135&34|55|131&
	 */
	function getRiskAnswer()
	{
		var riskAnswerStr = "",  // 征信答案字符串
		queId = null,  // 题目 id
		ansId = null;  // 答案 id
		$(_pageId+" #test_main li").each(function(){
			queId = $(this).children(".til").attr("id");
			ansId = $(this).find(".cont span[class='on']").attr("ans-id");
			riskAnswerStr += subid+"|"+queId+"|"+ansId+"&";
		});
		return riskAnswerStr;
	}
	/*查询风险测评题目*/
	function queryRiskQuestions()
	{
		var queryRiskParam = {
			"sub_id" : subid  // 34 风险测评  35 征信评分
		};
		service.queryQuestionList(queryRiskParam, function(data){
			if(data.error_no == "0")  
			{
				fillAllQuesArray($.parseJSON(data.results[0].result)); // 填充所有风险测评题目数组
				var questionHtml = "";
				for(var j=0; j<allQuesArray.length; j++)
				{
					var oneData  = allQuesArray[j]; // 取出一个问题
					questionHtml += createRiskAccessElement(oneData,j+1);
				}
				$(_pageId+" #test_main").html(questionHtml);
				BindSelAnswer();
			}
			else
			{
				layerUtils.iAlert(data.error_info);
			}
		});
	}
	
	/*填充所有题目数组*/
	function fillAllQuesArray(results)
	{
		
		for(var i = 0; i < results.length; i++)
		{
			var oneQuestion = {},  // 一个题目
			answerNo = 0;  // 答案编号  
			oneQuestion.que_id = results[i].que_id;  // 题目 id
			oneQuestion.name = results[i].name;  // 题目
			oneQuestion.answerArray = [];  // 答案数组
			for(var j = 0; j < results[i].answer.length; j++)
			{
				if(oneQuestion.que_id == results[i].answer[j].que_id)
				{
					oneQuestion.answerArray[answerNo] = {};   // 创建一个答案对象
					oneQuestion.answerArray[answerNo].ans_id = results[i].answer[j].ans_id;  // 答案 id
					oneQuestion.answerArray[answerNo].name = results[i].answer[j].name;  // 答案内容
					oneQuestion.answerArray[answerNo++].mark = results[i].answer[j].mark;  // 答案分数
				}
			}
			if(!quesIsExist(oneQuestion))   // 题目不存在时
			{
				allQuesArray.push(oneQuestion);  // 将题目放到题目数组中
			}
			oneQuestion = {};
			answerNo = 0;
			oneQuestion.que_id = results[i].que_id;  // 题目 id
			oneQuestion.name = results[i].name;  // 题目
			oneQuestion.answerArray = [];  // 答案数组
		}
	}
	
	/**
	 * 题目是否已经存在于题目数组中
	 * 返回 true 表示已经存在，false 不存在
	 */
	function quesIsExist(oneQuestion)
	{
		for(var i = 0; i < allQuesArray.length; i++)
		{
			if(oneQuestion.que_id == allQuesArray[i].que_id)
			{
				return true;
			}
		}
		return false;
	}
	
	/*填充题目到页面中*/
	function createRiskAccessElement(oneData,index)
	{
		var itemHtml = "";
		var itemHead = "";
		var itemElem = "";
		var ansArray = oneData.answerArray;
		var que_id = oneData.que_id
		// 问题标号
		var bgNum ="A";
		for(var i =0; i<ansArray.length; i++)  // 先遍历确定有多少题
		{
			var mark  = ansArray[i].mark;  // 答案分值
			var aname = ansArray[i].name;  // 答案描述
			var ansid = ansArray[i].ans_id;
			bgNum = changQuestionBgNum(i);
			itemElem += "<span href=\"javascript:void(0);\" ans-id=\""+ansid+"\" id = "+que_id+" >"+bgNum+". "+aname+"</span>";
		}
		itemHead = "<p  class=\"til\" id = "+que_id+">"+index+". "+oneData.name+"</p>";
		itemHtml = "<li>"+itemHead+"<p class=\"cont\" >"+itemElem+"</p></li>";
		return itemHtml;
	}
	
	/*绑定选择答案*/
	function BindSelAnswer()
	{
		appUtils.bindEvent($(_pageId+" #test_main span"),function(e){
				var queid   = $(this).attr("id");
//				if($(this).hasClass("on"))
//				{
////					$(this).parent().parent().prev("h5").css("color","red");  // 未选择答案，则将该题标记为红色
//					$(this).removeClass("on");
//				}
//				else
//				{
//					$(_pageId+" #test_main #"+queid).removeClass("on");
////					$(this).parent().parent().prev("h5").css("color","#666666");	// 题目红色标记恢复黑色
//					$(this).addClass("on");
//				}
				
				$(_pageId+" #"+queid).removeClass("on");
				
				$(this).toggleClass("on");
				
				e.stopPropagation();
		});
	}
	/* 改变问题答案 */
	function changQuestionBgNum(num)
	{
		var bgNum ="A";
		switch(num)
		{
			case 0: bgNum = "A"; break;
			case 1: bgNum = "B"; break;
			case 2: bgNum = "C"; break;
			case 3: bgNum = "D"; break;
			case 4: bgNum = "E"; break;
			case 5: bgNum = "F"; break;
			case 6: bgNum = "G"; break;
			default: bgNum ="其它";
		}
		return bgNum;
	}
	
	/*向外暴露的 JSON 对象*/
	var riskAssessment = {
			"init" : init,
			"bindPageEvent" : bindPageEvent,
			"destroy" : destroy
	};
	
	/*对外暴露 JSON 对象*/
	module.exports = riskAssessment;
});