define(function (require, exports, module) {
    var appUtils = require("appUtils");
    var layerUtils = require("layerUtils");
    var gconfig = require("gconfig");
    var global = gconfig.global;
    var utils = require("utils");
    var service = require("mobileService_xdt");
    var nativePluginService = require("nativePluginService");
    var external = require("external");

    /**
     * 首次进入模块的时候，调用
     */
    function firstLoadFunc() {
        external.callMessage({"funcNo": "50100", "moduleName": "ygt"});

        // 从原生中获取接入层地址
        var ygtURLParam = external.callMessage({
            "moduleName": "",
            "serverName": "YGT_SERVER_URL",
            "funcNo": "50112"
        });
        var mallURLParam = external.callMessage({
            "moduleName": "",
            "serverName": "MALL_SERVER_URL",
            "funcNo": "50112"
        });
        if (ygtURLParam && ygtURLParam.error_no == "0") {
            var ygtURL = ygtURLParam.results[0].url;
            global.serverPath = ygtURL + "/servlet/json";
        }
        if (mallURLParam && mallURLParam.error_no == "0") {
            var mallURL = mallURLParam.results[0].url;
            global.serverPath_mall = mallURL + "/servlet/json";
        }
    }

    /* 处理会话失效，长期未登录操作 */
    function filterLoginOut(data) {
    }

    /**
     * 每个页面校验
     */
    function checkPermission(checkInParam) {
        return true;
    }

    /**
     * 保存用户信息
     */
    function saveSessionUserInfo(userInfo) {
        saveDataToSession(userInfo);
    }

    /**
     * 删除用户信息
     */
    function clearSessionUserInfo() {
        appUtils.clearSStorage();
    }

    /**
     *处理模拟登陆失败
     */
    function ssoLoginFailed(data) {
        //这里可以加一些逻辑处理，根据返回的错误号，目前，我这里默认处理是：弹出提示信息，跳到登陆页面
        //弹出提示信息，跳到登陆页面
        layerUtils.iAlert(data.error_info);
        require.async("sso", function (module) {
            if (module.checkLoginRight()) {
                module.goTologin();
            }
        });
    }


    /*将数据保存到 session 中*/
    function saveDataToSession(loginResults) {
        appUtils.setSStorageInfo("fund_account", loginResults[0].fund_account);         // 资金账号
        appUtils.setSStorageInfo("client_id", loginResults[0].client_id);               // 客户号
        appUtils.setSStorageInfo("client_name", loginResults[0].client_name);           // 客户姓名
        appUtils.setSStorageInfo("trade_pwd", loginResults[0].password);                // 交易密码
        appUtils.setSStorageInfo("xy_fund_account", loginResults[0].xy_fund_account);   // 两融账号
        appUtils.setSStorageInfo("jsessionid", loginResults[0].jsessionid);             // jsessionid
        appUtils.setSStorageInfo("is_img", loginResults[0].is_img);                     // 是否有头像  0：没有 1：有
        appUtils.setSStorageInfo("img_data", "data:image/*;base64," + loginResults[0].img_data);      // 头像 base64
        appUtils.setSStorageInfo("_isLoginIn", "true");
        appUtils.setSStorageInfo("isShowXd", loginResults[0].isShowXd);               //我的小贷是否显示  1显示 0隐藏

        appUtils.setSStorageInfo("risk_level", loginResults[0].risk_level);           //测评等级
        appUtils.setSStorageInfo("client_gender", loginResults[0].client_gender);     //性别
        appUtils.setSStorageInfo("addr", loginResults[0].addr);                       //地址
        appUtils.setSStorageInfo("asset_prop", loginResults[0].asset_prop);           //权限
        appUtils.setSStorageInfo("jy_asset_prop", loginResults[0].jy_asset_prop);     //普通账户是否开通
        appUtils.setSStorageInfo("lc_asset_prop", loginResults[0].lc_asset_prop);     //理财账户是否开通
        appUtils.setSStorageInfo("xy_asset_prop", loginResults[0].xy_asset_prop);     //信用账户是否开通
    }

    /**
     * 友盟统计
     */
    function onEvent(tag, label, duration) {
        external.callMessage({"funcNo": "70007", "label": label});
    }

    var base = {
        "firstLoadFunc": firstLoadFunc,
        "checkPermission": checkPermission,
        "filterLoginOut": filterLoginOut,
        "saveSessionUserInfo": saveSessionUserInfo,
        "clearSessionUserInfo": clearSessionUserInfo,
        "ssoLoginFailed": ssoLoginFailed,
        "onEvent": onEvent
    };

    module.exports = base;
});