/**
 * 股票质押帮助类
 * @auther fc
 */
define(function(require, exports, module){
	var appUtils = require("appUtils");
	var formatNum = require("formatNum");
	var layerUtils = require("layerUtils");
	
	/**
	 * 填充股票持仓
	 * 股票质押和补充质押填充页面
	 * @desc 因为这两个页面相识 所以可以提出来
	 * @param results 查询股票持仓返回的数据results节点
	 * @param obj  填充的对象节点
	 * eg:
	 * @param shzzIsOpen 深圳资质开通情况 Y 开通 / I 开通中 / N 没有开通
	 * @param ispledge 是否为补充质押  true 补充质押 false 股票质押（初始交易）
	 */
	function fillStockList(results,obj,shzzIsOpen,ispledge){
		//填充持仓
		var fillstock = [];
		//head
		fillstock.push('<tr>');
		fillstock.push(	'<th width="35%" class="left">股票名称及代码</th>');
		fillstock.push(	'<th width="35%">最大可借金额</th>');
		fillstock.push(	'<th width="30%">质押数量</th>');
		fillstock.push('</tr>');
		
		//股票持仓的数量
		var reslen = (results instanceof Array && results.length)-0;
		
		//资质开通 上海资质第二天才开通
		// true 深圳没有开通 //  false 深圳开通了资质
		var shzzIsOpenFlag = shzzIsOpen != "Y";
		
		for(var i = 0; i < reslen; i++){
			var result = results[i];
			
			var exchangeType = result.exchange_type;//股票市场 2 沪A市 0 深A市
			var stkbal = result.enable_amount-0;//最大可质押股票数
			
			if(!ispledge){
				//判断股票是否是上海的 且 上海资质是否开通，如果没有开通后面就不用继续了
				//如果可交易股票数为0 则不予显示
				if((shzzIsOpenFlag && exchangeType == '2') || stkbal <= 0){
					continue;
				}
			}
			
			var stockName = result.stock_name.replace(/\ +/g,"");//股票名
			var stockCode = result.stock_code;//股票代码
			var coefficient = result.coefficient-0;//折算率
			var lastPrice = result.last_price-0;//折算价
			var warnLine = result.warn_line;//预警线
			var lowLine = result.low_line;//最低限
			var follow_line = result.follow_line;//关注比例
			var exchange_type_name = result.exchange_type_name;//市场名称
			
			var max_loan_money = 0;
			
			//补充质押不计算折算率
			if(!ispledge){
				//保留两位小数 不进位
				max_loan_money = toFixed2(coefficient*stkbal*lastPrice,2);
			}else{
				max_loan_money = toFixed2(stkbal*lastPrice,2);
			}
			//stock
			fillstock.push('<tr>');
			fillstock.push(	'<td class="left">');
			fillstock.push(		'<div class="gp_title">');
			fillstock.push(			'<h5>'+stockName+'</h5>');
			fillstock.push(			'<p>'+ stockCode+'</p>');
			fillstock.push(		'</div>');
			fillstock.push(	'</td>');
			fillstock.push(	'<td><span class="gp_dataspan" maxloan="'+max_loan_money+'">'+formatNum.formatMoney(max_loan_money)+'</span></td>');
			fillstock.push(	'<td>');
			//此节点存放股票信息
			fillstock.push(		'<div class="gp_numbox" stockname="'+stockName+'" stockcode="'+stockCode+'"'
								+' max_loan_money="'+max_loan_money+'" enable_amount="'+stkbal+'"'
								+' exchange_type="'+exchangeType+'" coefficient="'+coefficient+'"'
								+' stock_price="'+lastPrice+'" warnline="'+warnLine+'" lowline="'+lowLine+'"'
								+' follow_line="'+follow_line+'" exchange_type_name="'+exchange_type_name+'">');
			fillstock.push(			'<h5><input class="txt" type="tel" value="0">股</h5>');
			fillstock.push(			'<div class="jd"><span style="width:0%;"><b></b></span></div>');
			fillstock.push(			'<p class="info"><span>0</span><span>'+stkbal+'</span></p>');
			fillstock.push(		'</div>');
			fillstock.push(	'</td>');
			fillstock.push('</tr>');
		}
		
		obj.html(fillstock.join(""));
		
	}
	
	/**
	 * 股票质押持仓绑定事件
	 * 滑动事件
	 * @pram sumobj 滑块的点
	 * eg : $(_pageId + ' div[class="jd"] span b')
	 * @param callback 回调事件(确定选择的股数的回调事件)
	 * @param ispledge 是否是补充质押 true 补充质押 false 股票质押
	 */
	function stockNumEvent(sumobj,callback,ispledge){
		
		//手机上的
		appUtils.bindEvent(sumobj, function(e){
			//method
			pledgeStockEvent(e,$(this),callback,ispledge);
			e.stopPropagation();
		},"touchstart");
		
		//鼠标点击 滑动条 直接定位
		appUtils.bindEvent(sumobj.parent().parent(), function(e){
			//method
			pledgeStockEvent(e,$(this).children().children(),callback,ispledge);
			e.stopPropagation();
		},"mouseover");
		
		//电脑上的
		appUtils.bindEvent(sumobj, function(e){
			appUtils.bindEvent($(this), function(e){
				//method
				pledgeStockEvent(e,$(this),callback,ispledge);
				e.stopPropagation();
			},'mousedown');
			e.stopPropagation();
		},"mouseover");
		
		//股票质押输入框dom
		var $inputDom = $(sumobj).parent().parent().prev().find("input[type='tel']");
		//质押输入框
		appUtils.bindEvent($inputDom,function(e){
			if(!ispledge){
				//股票质押页面
				//借款天数
				var days = $("#business_borrowApply #selCreditTime").attr("credit-time");
				if(!days){
					layerUtils.iAlert("请选择借款时间");
					$(this).val(0);
					return false;
				}
			}
			if (this.value.match("^0") != null) {
				//去掉第一个 0
				this.value = this.value = this.value.replace(/\b(0+)/gi,"");
			}
			
			var checkNum = /^[0-9]\d*$/;
			if($(this).val()!=""){
				if(!checkNum.test($(this).val())){
					$(this).val(0);
				}
			}
			 //质押的股数
			 var tnum = $(this).val()-0;
			 //总股数（可质押）'
			 var stnum = $(this).parent().parent().attr("enable_amount")-0;
			 //class="jd" 滑动的条 dom节点
			 var $parent = $(this).parent().next();
			 //质押股数变化 dom节点
			 var $stocknum = $(this);
			 
			//method
			numCal(tnum,stnum,$parent,$stocknum,callback,ispledge);
			
			e.stopPropagation();
		},"input");
		
		//焦点yichu
		appUtils.bindEvent($inputDom,function(e){
			//质押的股数
			var tnum = $(this).val()-0;
			//总股数（可质押）'
			var stnum = $(this).parent().parent().attr("enable_amount")-0;
			//class="jd" 滑动的条 dom节点
			var $parent = $(this).parent().next();
			//质押股数变化 dom节点
			var $stocknum = $(this);
			 
			tnum = tnum - tnum%100;
			
			numCal(tnum,stnum,$parent,$stocknum,callback,ispledge);
			e.stopPropagation();
		},"blur");
		
	}
	
	/**
	 * 股票质押事件
	 * @desc 缺点：在电脑上 没有实现点击滑块条直接定位，手机上支持
	 * @param event 事件
	 * @param obj   股票滑块对象 为那个点的节点对象
	 * @param callback 回调事件
	 * @param ispledge 是否是补充质押 true 补充质押 false 股票质押
	 * 
	 * 股票质押 和 补充质押可能 在选择股数上不一样
	 */
	function pledgeStockEvent(event,obj,callback,ispledge){
		
		//股票质押(初始交易)先决条件
		// 选择借款期限
		if(!ispledge){
			//股票质押页面
			//借款天数
			var days = $("#business_borrowApply #selCreditTime").attr("credit-time");
			if(!days){
				layerUtils.iAlert("请选择借款时间");
				return false;
			}
		}
		
		var e = event||window.event;
		var x,z,drag_ = false;
		//class="jd" 滑动的条
		var $parent = $(obj).parent().parent();
		//总长度 px
		var len = $parent.width();
		//质押股数变化
		var $stocknum = $parent.prev().find('input[type="tel"]'); 
		//总股数
		var stnum = $parent.next().find('span:eq(1)').text()-0;
		//当前的长度
		var temp0 = $parent.children().css('width').replace("px","")-0;
		//股票滑块 滑动的分级
		
		switch(e.type){
		case 'touchstart':
			drag_ = true;
			e.preventDefault();
			if (!e.originalEvent.touches.length) return;
			x = e.originalEvent.touches[0].clientX;
			
			appUtils.bindEvent(obj,function(e){
				if(!drag_)return false;
				e.preventDefault();
			    if (!e.originalEvent.touches.length) return;
			    var touch = e.originalEvent.touches[0];
				z = temp0 + touch.clientX-x;
				z = z > len ? len : z;
				z = z < 0 ? 0 : z;
				z = (z/len)*100;
				//整股 质押数量
				var tnum = stnum*z/100;
				tnum = tnum - tnum%100;
				//method
				numCal(tnum,stnum,$parent,$stocknum,callback,ispledge);
				e.stopPropagation();
			},'touchmove');
			
			appUtils.bindEvent(obj,function(e){
				drag_ = false;
				e.stopPropagation();
			},'touchend');
			
			break;
		case 'mousedown':
			drag_ = true;
			x = e.clientX;
			appUtils.bindEvent(obj,function(e){
				if(!drag_)return false;
				z = temp0 + e.clientX-x;
				z = z > len ? len : z;
				z = z < 0 ? 0 : z;
				z = (z/len)*100;
				//整股 质押数量
				var tnum = stnum*z/100;
				tnum = tnum - tnum%100;
				//method
				numCal(tnum,stnum,$parent,$stocknum,callback,ispledge);
				e.stopPropagation();
			},'mousemove');
			
			appUtils.bindEvent(obj,function(e){
				drag_ = false;
				e.stopPropagation();
			},'mouseup');
			break;
		case 'mouseover':
			//鼠标点击 滑动条 直接定位
			drag_ = true;
			appUtils.bindEvent(obj.parent().parent(),function(e){
				  if(!drag_)return false;
		          //元素距离左边的长度
		          var yleft = $(this).offset().left;
		          //点击点距离左边的长度
		          var dleft = e.clientX;
		          z = dleft - yleft;
		          z = z > len ? len : z;
		  		  z = z < 0 ? 0 : z;
		  		  z = (z/len)*100;
		  		  //整股 质押数量
		  		  var tnum = stnum*z/100;
		  		  tnum = tnum - tnum%100;
		          //method
		          numCal(tnum,stnum,$parent,$stocknum,callback,ispledge);
		          e.stopPropagation();
			},'mousedown');
			
			appUtils.bindEvent(obj.parent().parent(),function(e){
				drag_ = false;
				e.stopPropagation();
			},'mouseup');
		    
			break;
			default:
				break;
		}
		
	}
	
	/**
	 * 股票质押 滑块
	 * @param tnum 质押的股数
	 * @param stnum 总股数（可质押）
	 * @param $parent //class="jd" 滑动的条 dom节点
	 * @param $stocknum 质押股数变化 dom节点
	 * @param callback 回调函数
	 * @param ispledge  是否是补充质押 true 补充质押 false 股票质押
	 */
	function numCal(tnum,stnum,$parent,$stocknum,callback,ispledge){
		
		if(tnum > stnum){
			tnum = stnum;
		}
		
		var z = (tnum/stnum)*100;
		z = (z > 100)?z=100:z;
		z = (z < 0)?0:z;
		$parent.children().css('width',z+'%');
		
		$stocknum.val(tnum);
		
		//获取选择的股票信息 dom节点
		var $stockinfo = $parent.parent();
		//获取股票市场
		var exchangetype = $stockinfo.attr("exchange_type")-0;
		//获取折算率
		var coefficient = $stockinfo.attr("coefficient")-0;
		//协议价
		var stock_price = $stockinfo.attr("stock_price")-0;
		//计算质押金额
		var pledgemoney = 0;
		if(!ispledge){
			pledgemoney = toFixed2(coefficient*tnum*stock_price,2);
		}else{
			pledgemoney = toFixed2(tnum*stock_price,2);
		}
		
		//如果是初始交易才会走以下
		if(!ispledge){
			
			//计算经手费
			var jsfree = calcBrokerage(pledgemoney,tnum,exchangetype);
			//计算质押登记费
			var djfree = calcRegisterFee(tnum);
			
			//获取借款期限
			var day = $("#business_borrowApply #selCreditTime").attr("credit-time");
			//获取借款利率
			var rate = $("#business_borrowApply #selCreditTime").attr("credit-rate");
			
			//计算利息
//			var interet = calcInteret(day,rate,pledgemoney);
			
			//给选择的股票 attr 经手费 和 登记费
			$stockinfo.attr({"jsfree":jsfree,"djfree":djfree});
		}
		//给选择的股票 attr 质押金额
		$stockinfo.attr({"pledgemoney":pledgemoney,"pledgenum":tnum});
		
		/*
		 * 初始交易 
		 * 	如果超过了 最大可借款金额那么就 回滚 显示 滑块原来的位置和数据，并提示
		 * 补充质押
		 */
		//回调方法
		if(callback){
			callback();
		}
	}
	
	/**
	 * 保留小数
	 * 不四舍五入
	 * @param num 数字
	 * @param len 保留的小数位数
	 * 
	 * @return 
	 */
	function toFixed2(num,len){
		len = len-0||0;
		if(len<0) len=0;
		var num = num+"";
		var dian = num.indexOf(".");
		if(dian < 0) return num-0;
		return num.substring(0,dian+1+len)-0;
	}
	
	/***************************计算手续费 开始*********************************/
	/**
	 * 计算经手费
	 * 上海市场按每笔借款金额的0.01‰收取，起点5元人民币，最高不超过100元人民币。
     * 深圳市场按每笔借款质押标的证券面值1‰收取，最高不超过100元人民币。
	 * @param pledgeMoney 
	 * @param pledgeAmount 
	 * @param market 
	 */
	function calcBrokerage(pledgeMoney,pledgeAmount,market){
		
		pledgeMoney = pledgeMoney-0;
		pledgeAmount = pledgeAmount-0;
		market = market-0;
		
		//质押股数为0
		if(pledgeAmount <= 0){
			return 0;
		}
		
		//从缓存获取
		var borrowMoney_deelFee = appUtils.getSStorageInfo("deelFee");
		if(!borrowMoney_deelFee){
			layerUtils.iAlert("未获取到交易费用，请重试！");
			return 0;
		}
		
		borrowMoney_deelFee = JSON.parse(borrowMoney_deelFee);
		
		var brokerage = 0;
		// 0 是深A  2是沪A
		 if(market == 0){
			 brokerage = (pledgeAmount*(borrowMoney_deelFee.under_critical_sz-0)).toFixed(2) - 0;
			 if(brokerage>(borrowMoney_deelFee.max_charge_sz-0)){
				 brokerage = borrowMoney_deelFee.max_charge_sz-0;//最高不超过100元人民币。
			 }else if(brokerage<(borrowMoney_deelFee.jsfee_sz-0)){
				 brokerage = borrowMoney_deelFee.jsfee_sz-0;
			 }
		 }else if(market == 2){
			 brokerage = (pledgeMoney*(borrowMoney_deelFee.under_critical_sh-0)).toFixed(2) - 0;
			 if(brokerage>(borrowMoney_deelFee.max_charge_sh-0)){
				 brokerage = borrowMoney_deelFee.max_charge_sh-0;//最高不超过100元人民币。
			 }else if(brokerage<(borrowMoney_deelFee.jsfee_sh-0)){
				 brokerage = borrowMoney_deelFee.jsfee_sh-0;
			 }
		 }
		 
		return brokerage;
	}
	
	/**
	 * 计算质押登记费
	 * 股票500万股以下（含）部分按该部分面值的1‰收取，超500万股的部分按该部分面值的0.1‰收取，起点100元。
     * 基金500万份以下（含）部分按该部分面值的0.5‰收取，超500万份的部分按该部分面值的0.05‰收取，起点100元。
	 * 债券500万元以下（含）部分按该部分面值的0.5‰收取，超500万元的部分按该部分面值的0.05‰收取，起点100元。
	 * @param pledgeNum 质押股数
	 */
	function calcRegisterFee(pledgeNum)
	{
		//质押股数为0
		if(pledgeNum <= 0){
			return 0;
		}
		
		//从缓存获取
		var borrowMoney_deelFee = appUtils.getSStorageInfo("deelFee");
		if(!borrowMoney_deelFee){
			layerUtils.iAlert("未获取到交易费用，请重试！");
			return 0;
		}
		
		borrowMoney_deelFee = JSON.parse(borrowMoney_deelFee);
		
		var registerFee = 0,  // 质押登记费
			currPledgeNum = pledgeNum-0;  // 当前质押股数
		if(currPledgeNum<=(borrowMoney_deelFee.critical-0)){//临界费用值 500w
			registerFee = currPledgeNum*(borrowMoney_deelFee.under_critical-0);//临界值之内 0.001
			if(registerFee<(borrowMoney_deelFee.zyfee-0)){
				registerFee = borrowMoney_deelFee.zyfee-0;
			}
		}else if(currPledgeNum>(borrowMoney_deelFee.critical-0)){
			registerFee = (currPledgeNum-borrowMoney_deelFee.critical-0)*(borrowMoney_deelFee.over_critical-0)
						+ (borrowMoney_deelFee.critical-0)*(borrowMoney_deelFee.under_critical-0);
		}
		return registerFee;
	}
	
	/**
	 * 计算利息
	 * @desc 这里不考虑随借款随还
	 * @param creditTime 借款时间 (天数)
	 * @param creditRate 借款利率
	 * @param creditQuantity 借款金额 
	 */
	function calcInteret(creditTime,creditRate,creditQuantity)
	{
		var interest = 0;
		interest = (creditTime / 360) * creditRate * creditQuantity;  // 利息=((天数/360)*利率*(金额))/100
		interest = interest.toFixed(2);  // 保留两位小数 
		return interest;
	}
	/***************************计算手续费 结束*********************************/
	
	/**
	 * 股票的长度
	 * @param length 股票数量的长度
	 * eg: 股票数量 9999 那么股票的长度 为 1000
	 * return 返回股票的质押 滑块的 分段 1000 按照整股分 只能分为 10份
	 */
	function fragmentInteger(length) {
		return (('1'+(1 / Math.pow(10, length)).toFixed(length).substr(2,length-1))-0)/100;
	}
	
	/*向外暴露的 JSON 对象*/
	var stockhelp = {
			"fillStockList":fillStockList,
			"stockNumEvent":stockNumEvent,
			"calcInteret":calcInteret,
			"calcBrokerage":calcBrokerage,
			"toFixed2":toFixed2
	};
	
	/*对外暴露 JSON 对象*/
	module.exports = stockhelp;
});
