/**
 * 通用工具类，将项目中的公用方法抽出来
 */
define(function (require, exports, module) {
    var appUtils = require("appUtils"),
        layerUtils = require("layerUtils"),
        validatorUtil = require("validatorUtil"),
        gconfig = require("gconfig"),
        global = gconfig.global,
        external = require("external");

    /**
     * 获取 session 中的用户数据
     */
    function getUserInfoInSession() {
        var userInfo = appUtils.getSStorageInfo("userInfo");  // 先获取 session 中的 userInfo
        if (userInfo)  // userInfo 不为空，就解密
        {
            userInfo = appUtils.getSStorageInfo("userInfo");
            userInfo = JSON.parse(userInfo);
        }
        return userInfo;
    }

    /**
     * 向 session 中的 userInfo 添加数据
     * 注意：调用这个方法之前，必须要确保 userInfo 不为空
     * @param key 当 key 为 String 类型时，存入的值的名称，当 key 为对象时，变量 key 对象的所有属性，将所有属性添加到 userInfo 中，此时 val 传 null 或 不传
     * @param val 存入的值
     */
    function addDataToUserInfo(key, val) {
        var userInfo = getUserInfoInSession();
        if (!userInfo)  // 为空结束方法
        {
            return;
        }
        if (key instanceof Object)  // 是对象时
        {
            for (var p in key) {
                if (key.hasOwnProperty(p)) {
                    userInfo[p] = key[p];   // 将 key 中所有数据添加到 userInfo
                }
            }
        }
        else {
            userInfo[key] = val;  // 添加数据
        }
        appUtils.setSStorageInfo("userInfo", JSON.stringify(userInfo));  // 重新设置 session 中的 userInfo
    }

    /**
     * 从 userInfo 中删除数据
     * @param key 要删除的属性名，如果 key 为数组，则删除 userInfo 中属性和数组中元素相同的所有属性
     */
    function delDataFromUserInfo(key) {
        var userInfo = getUserInfoInSession();
        if (key instanceof Array)  // 如果 key 是数组
        {
            for (var i = 0; i < key.length; i++) {
                delete userInfo[key[i]];  // 删除与 key[i] 对应的属性
            }
        }
        else   // key 不是数组时
        {
            delete userInfo[key];  // 删除与 key 对应的属性
        }
        appUtils.setSStorageInfo("userInfo", JSON.stringify(userInfo), true);  // 重新设置 session 中的 userInfo
    }

    /**
     * 请求 action
     * @param param 请求参数
     * @param succCallback 请求成功的回调函数
     * @param isLastReq 是否显示等待层，默认为true
     * @param isShowWait 是否显示等待层，默认为true
     * @param timeOutFunc 超时的处理函数
     * @param dataType 预期后台返回的数据类型，默认为 text
     */
    function invokeAction(param, succCallback, isLastReq, isShowWait, timeOutFunc, dataType) {
        isLastReq = isLastReq ? isLastReq : true;
        isShowWait = isShowWait ? isShowWait : true;
        isShowWait ? layerUtils.iLoading(true) : "";
        dataType = dataType ? dataType : "text";
        var url = param["url"];
        delete param[url];
        $.ajax({
            "url": url,
            "dataType": dataType,
            "type": "post",
            "data": param,
            "success": function (data) {
                (isShowWait && isLastReq) ? layerUtils.iLoading(false) : "";
                succCallback(data);
            },
            "error": function (xhr, errMsg, error) {
                if (errMsg == "timeout" && timeOutFunc)   // 如果是超时并且超时函数不为空
                {
                    timeOutFunc();  // 执行超时函数
                }
            },
            "xhrFields": {"withCredentials": true}  // 跨域保持会话
        });
    }


    /**
     * 激活输入框（类似于聚焦）
     */
    function inputActive(ui) {
        ui.addClass("active");
        var curWord = ui.children("em").html();
        if (curWord == ui.attr("data-role")) {
            ui.children("em").html("");
        }
        if (ui.parents(".input_text").siblings(".input_text").children(".input_custom").hasClass("active")) {
            var allInput = ui.parents(".input_text").siblings(".input_text");
            for (var i = 0; i < allInput.length; i++) {
                var curData = allInput.eq(i).children(".input_custom").children("em").html();
                var oldData = allInput.eq(i).children(".input_custom").attr("data-role");
                allInput.eq(i).children(".input_custom").removeClass("active");
                if (curData == "") {
                    allInput.eq(i).children(".input_custom").children("em").html(oldData);
                    allInput.eq(i).children(".input_custom").removeClass('active');
                }
            }
        }
    }

    var utils = {
        "getUserInfoInSession": getUserInfoInSession,
        "invokeAction": invokeAction,
        "addDataToUserInfo": addDataToUserInfo,
        "delDataFromUserInfo": delDataFromUserInfo,
        "inputActive": inputActive
    };

    module.exports = utils;
});