﻿define(function (require, exports, module) {
        var appUtils = require("appUtils");
        var gconfig = require("gconfig");
        var global = gconfig.global;
        var validata = require("validatorUtil");
        var layerUtils = require("layerUtils");
        var _pageId = "#me_billsChart";
        var mobileService = require("mobileService");
        var external = require("external");

        var HIscroll = require("hIscroll");
        var myHIscroll = null;

        var currentYear = 0,   //当前年份
            currentMonth = 0,  //当前月份
            currentDay = 0,    //当前日期
            preYear = 0,       //前一个月的年份
            preMonth = 0,      //前一个月
            nextYear = 0,      //后一个月的年份
            nextMonth = 0;     //后一个月

        function init() {
            //初始化当前时间参数
            var currentDate = new Date();
            currentYear = currentDate.getFullYear();
            currentMonth = currentDate.getMonth() + 1;//js的date对象的月数是从0开始计数的(如10表示11月)
            currentDay = currentDate.getDate();

            var param = modifyValueOfMonth(currentYear, currentMonth, "prev");
            preMonth = param.month;
            preYear = param.year;

            param = modifyValueOfMonth(currentYear, currentMonth, "next");
            nextMonth = param.month;
            nextYear = param.year;

            showInfosOfMonthAndYear();   //显示年月信息
            showBillOfCurrentMonth();   //显示当前月的账单
        }

        /* 显示年月信息 */
        function showInfosOfMonthAndYear() {
            $(_pageId + " #current_month").text(currentYear + "年" + currentMonth + "月");
            $(_pageId + " .month_box .prev_month").text(preMonth + "月");
            $(_pageId + " .month_box .next_month").text(nextMonth + "月");
        }

        /* 显示当前月的账单 */
        function showBillOfCurrentMonth() {
            var monthStr = currentMonth < 10 ? "0" + currentMonth : currentMonth,
                dayStr = currentDay < 10 ? "0" + currentDay : currentDay;

            var start_date = currentYear + "-" + monthStr + "-01",
                end_date = currentYear + "-" + monthStr + "-" + dayStr;
            //查询我的账户当前月的账单
            QueryMyBill(start_date, end_date);
        }

        /* 绑定事件*/
        function bindPageEvent() {
            //返回上一个页面
            appUtils.bindEvent($(_pageId + " .icon_back"), function () {
                appUtils.pageBack();
                // appUtils.pageInit("me/billsChart", "me/bills", {});
            });

            //前一个月
            appUtils.bindEvent($(_pageId + " .month_box .prev_month"), function () {
                var dateParam = getDateParam(preYear, preMonth);
                QueryMyBill(dateParam.start_date, dateParam.end_date);
                updateYearAndMonth("prev");    //更新年月信息
            });

            //后一个月
            appUtils.bindEvent($(_pageId + " .month_box .next_month"), function () {
                var dateParam = getDateParam(nextYear, nextMonth);
                QueryMyBill(dateParam.start_date, dateParam.end_date);
                updateYearAndMonth("next");   //更新年月信息
            })

            /* 更新年月信息 */
            function updateYearAndMonth(flag) {
                var param = modifyValueOfMonth(currentYear, currentMonth, flag);
                currentMonth = param.month;
                currentYear = param.year;

                param = modifyValueOfMonth(currentYear, currentMonth, "prev");
                preMonth = param.month;
                preYear = param.year;

                param = modifyValueOfMonth(currentYear, currentMonth, "next");
                nextMonth = param.month;
                nextYear = param.year;

                showInfosOfMonthAndYear();  //显示年月信息
            }
        }

        /* 销毁 */
        function destroy() {
            if (myHIscroll) {
                myHIscroll.destroy();
                myHIscroll = null;
            }
            mobileService.destroy();
        }

        /* 初始化滑动组件 */
        function initScroller() {
            if (!myHIscroll) {
                var config = {
                    "wrapper": $(_pageId + " #wrapper_myChart"), // wrapper元素，必传
                    "scroller": $(_pageId + " #scroller_myChart"), // scroller元素，必传
                    "perCount": 1, // 每个可视区域显示的子元素，就是每个滑块区域显示几个子元素，必传
                    "showTab": true, // 是否有导航点，必传
                    "tabDiv": $(_pageId + " #tag_nav"), // 导航点集合对象，config.showTab为true时必传
                    "auto": false, // 是否自动播放，非必传，默认为false
                    "onScrollEnd": function () {
                        var chartType = $(_pageId + " .order_num em[class='current active']").attr("chartType");  //expend 支出;  income 收入
                        if (chartType === "expend") {
                            $(_pageId + " .dzd_infolist ul.income").hide();     // 隐藏收入详情
                            $(_pageId + " .dzd_infolist ul.expend").show();     // 显示支出详情
                        }
                        else if (chartType === "income") {
                            $(_pageId + " .dzd_infolist ul.expend").hide();     // 隐藏支出详情
                            $(_pageId + " .dzd_infolist ul.income").show();     // 显示收入详情
                        }
                    } // 滑动完毕后的自定义处理函数，非必传
                };
                myHIscroll = new HIscroll(config);
            }
        }

        /* 查询我的账户某个时间段的账单 */
        function QueryMyBill(start_date, end_date) {
            var param = {
                "branch_no": appUtils.getSStorageInfo("branch_no"),
                "fund_account": appUtils.getSStorageInfo("fund_account"),
                "client_id": appUtils.getSStorageInfo("client_id"),
                "start_date": start_date,
                "end_date": end_date,
                "packaged_type": "1"
            }
            mobileService.queryAccountBack(param, function (data) {
                    var error_no = data.error_no;
                    var error_info = data.error_info;
                    if (error_no == "0") {
                        //显示收入和支出账单
                        showIncomeAndSpendBills(data.spend, data.revenue, data.total[0]);
                    }
                    else {
                        layerUtils.iLoading(false);
                        layerUtils.iAlert(error_info);
                    }
                }
            );
        }

        /* 显示收入和支出账单 */
        function showIncomeAndSpendBills(spend, income, total) {
            //显示支出信息(这个数据与效果有差别与bus的同事沟通一下，就是充值与提现)
            showBillInfo(spend, ["充值", "证劵买入", "理财买入", "基金买入"], $(_pageId + " ul.expend li"), total.total_spend, "expend_imgbox", "总支出");

            //显示收入信息
            showBillInfo(income, ["提现", "证劵卖出", "理财赎回", "基金赎回"], $(_pageId + " ul.income li"), total.total_revenue, "income_imgbox", "总收入");

            //初始化滑动组件
            initScroller();
        }

        /* 显示账单信息 */
        function showBillInfo(infos, names, liDom, total, id, title) {
            var money = "",    //充值或是提现
                stock = "",    //证券的买入与卖出
                finance = "",  //理财的买入与赎回
                fund = "";     //基金的买入与赎回
            //显示列表信息
            for (var i = 0, len = infos.length; i < len; i++) {
                var index = -100;
                switch (infos[i].business_name) {
                    case names[0]:
                        index = 0, money = infos[i].occur_balance_all;     //index为该项li标签在HTML中的序号
                        break;
                    case names[1]:
                        index = 1, stock = infos[i].occur_balance_all;
                        break;
                    case names[2]:
                        index = 2, finance = infos[i].occur_balance_all;
                        break;
                    case names[3]:
                        index = 3, fund = infos[i].occur_balance_all;
                        break;
                    default :
                        break;
                }
                liDom.eq(index).find("span.amount").html(formatMoney(infos[i].occur_balance_all));  //设置金额
                liDom.eq(index).find("span.percent").html(infos[i].percentage);        //设置百分比
            }

            //画资金图
            var numStrArray = [money, stock, finance, fund];
            var colorArray = id === "expend_imgbox" ? ["#fd8056", "#e64f47", "#ffd762", "#f2b04b"] : ['#72acea', '#53c5ac', '#74c457', '#44c8e5']
            if (total == 0.00) {  //总额为0时的特殊安排
                colorArray = ["#cfcfcf", "#cfcfcf", "#cfcfcf", "#cfcfcf"];
            }
            myChart(id, getRatioArray(numStrArray, total), colorArray, formatMoney(total), title);
        }

        /* 获得每一项在总的份额的比率 */
        function getRatioArray(numStrArray, total) {
            if (total == 0.00) {   //总额为0时的特殊安排
                return [1, 0, 0, 0];
            }

            var num = -1,
                ratioArray = [];
            total = new Number(total);
            for (var i = 0, len = numStrArray.length; i < len; i++) {
                num = new Number(numStrArray[i]);
                ratioArray[i] = num / total;
            }
            return ratioArray;
        }

        /* 获取对账单时间段的标准格式参数 */
        function getDateParam(year, month) {
            var daysOfMonthDay = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31],
                endDay = "";
            if ((year % 4 === 0 && year % 100 != 0) || year % 400 === 0) {  //闰年
                endDay = "-29";
            }
            else {
                endDay = "-" + daysOfMonthDay[month];
            }

            month = (month < 10 ? "-0" : "-") + month;

            return {
                "start_date": year + month + "-01",
                "end_date": year + month + endDay
            }
        }

        /* 让月份加一个月或是减少一个月 */
        function modifyValueOfMonth(year, month, flag) {
            if (flag === "prev") {
                if (month === 1) {
                    month = 12;
                    year--;
                }
                else {
                    month--;
                }
            }
            else if (flag === "next") {
                if (month === 12) {
                    month = 1;
                    year++;
                }
                else {
                    month++
                }
            }
            return {
                "month": month,
                "year": year
            }
        }

        /**
         * 画饼图 资金分布
         */
        function myChart(id, percent, color, total, title) {
            var cxt;
            var c = document.getElementById(id);
            cxt = c.getContext("2d");

            //白色底
            drawCircle(cxt, 0, 90, 90, 90, 0, Math.PI * 2, true, "#FFFFFF");
            var start = Math.PI * 1.5;
            var percents = 0;
            for (var i = 0; i < percent.length; i++) {
                percents = percent[i] < 0 ? 0 : percent[i];
                //彩色圆环
                drawCircle(cxt, -1, 90, 90, 88, start, Math.PI * 2 * percents + start, false, color[i]);
                //圆环白色间隔
                start = Math.PI * 2 * percents + start;
            }
            //灰色中心外圈 白色
            drawCircle(cxt, 0, 90, 90, 50, 0, Math.PI * 2, true, "#FFFFFF");
            cxt.font = "18px Arial";
            cxt.fillStyle = "black";
            //total为接口查询计算出的账户总资产
            cxt.fillText(title, 65, 75);
            cxt.font = "13px Arial";
            cxt.fillStyle = "black";
//            cxt.fillText(total, 55, 103);
            cxt.fillText(total, (90 - (total.length) * 3), 103);    //动态改变使数字显示在中间位置
        }

        /**
         * @param cxt 画笔对象
         * @param type 结束画笔类型
         * @param x x坐标
         * @param y y坐标
         * @param r 半径
         * @param start 画圆起始位置
         * @param end 画圆结束位置
         * @param direction flase 逆时针画 true 顺时针画
         * @param style 样式
         */
        function drawCircle(cxt, type, x, y, r, start, end, direction, style) {
            cxt.fillStyle = style;
            cxt.beginPath();
            cxt.arc(x, y, r, start, end, direction);
            if (type == 0) {
                cxt.closePath();
            } else {
                cxt.lineTo(x, y);
            }
            cxt.fill();
        }

        /*格式化金额*/
        function formatMoney(s, n) {
            if (s == "") return "0.00";

            n = n > 0 && n <= 20 ? n : 2;
            s = parseFloat((s + "").replace(/[^\d\.-]/g, "")).toFixed(n) + "";
            var l = s.split(".")[0].split("").reverse(), r = s.split(".")[1];
            t = "";
            for (i = 0; i < l.length; i++) {
                t += l[i] + ((i + 1) % 3 == 0 && (i + 1) != l.length ? "," : "");
            }
            return t.split("").reverse().join("") + "." + r;
//            return "￥" + t.split("").reverse().join("") + "." + r;
        }


        var billsChart = {
            "init": init,
            "bindPageEvent": bindPageEvent,
            "destroy": destroy
        };
        module.exports = billsChart;
    }
)
;