define(function (require, exports, module) {
    /* 私有业务模块的全局变量 begin */
    var appUtils = require("appUtils");
    var layerUtils = require("layerUtils");
    var gconfig = require("gconfig");
    var external = require("external");
    var mobileService = require("mobileService");
    var _pageId = "#me_serviceHall";

    function init() {
        var pageParam = appUtils.getPageParam("isDirectExit");
        if (pageParam) {
            appUtils.setSStorageInfo("hall_isDirectExit", pageParam.split("#")[0]);
            getCSTelephone(); // 获取客户号
        }
        queryQuestionInfo();
    }

    /* 查询所有的问题 */
    function queryQuestionInfo() {
        mobileService.queryQuestionList({}, function (data) {
            if (data.error_no == "0") {
                showInfoToHTML(data.columns, data.questions);
            } else {
                layerUtils.iLoading(false);
                layerUtils.iAlert(data.error_info);
            }
        });
    }

    function showInfoToHTML(columnList, questionList) {
        var columnStr = "";
        for (var i = 0, len = columnList.length; i < len; i++) {
            columnStr += "<li column_val='" + columnList[i].item_value + "'><a href='javascript:void(0)'>" + columnList[i].item_name + "</a></li>";
        }
        $(_pageId + " #column_list").html(columnStr).find("li:first").addClass("current");

        var quesStr = "";
        for (var q = 0, qLen = questionList.length; q < qLen; q++) {
            quesStr += "<li style='display: none;' ques_id='" + questionList[q].ques_id + "' column_val='" + questionList[q].enum_value + "'><a href='javascript:void(0)'>" + questionList[q].question_name + "</a></li>";
        }
        var columnVal = $(_pageId + " #column_list li:first").attr("column_val");
        $(_pageId + " #question_list").html(quesStr).find("li[column_val='" + columnVal + "']").show();
    }

    function bindPageEvent() {
        // 问题类型预绑定事件
        appUtils.preBindEvent($(_pageId + " #column_list"), "li", function () {
            $(_pageId + " #column_list li").removeClass("current");
            $(this).addClass("current");

            var columnVal = $(this).attr("column_val");
            $(_pageId + " #question_list li").hide().filter("[column_val='" + columnVal + "']").show();
        });

        // 各个问题的预绑定事件
        appUtils.preBindEvent($(_pageId + " #question_list"), "li", function () {
            appUtils.pageInit("me/serviceHall", "me/showAnswer", {"quesId": $(this).attr("ques_id")});
        });

        // 搜索事件
        appUtils.bindEvent($(_pageId + " #search"), function () {
            var columnVal = $(_pageId + " #column_list li:first").attr("column_val");
                        appUtils.pageInit("me/serviceHall", "me/search", {
                        	"quesStr": $(_pageId + " #question_list").html(),
                        	"columnVal": columnVal
                        	});
        });

        // 联系客服
        appUtils.bindEvent($(_pageId + " #contact_cs"), function () {
            var csTelephone = appUtils.getSStorageInfo("csTelephone");  // 客服电话
            if (csTelephone) {
                var callType = "";
                if (gconfig.platform == 1) { //android
                    callType = "0";
                } else if (gconfig.platform == 2) { //ios
                    callType = "1";
                }
                external.callMessage({
                    "funcNo": "50220",
                    "telNo": csTelephone,
                    "callType": callType
                });
            } else {
                layerUtils.iAlert("客户电话不存在！");
            }
        });

        // 提问事件
        appUtils.bindEvent($(_pageId + " #ques_btn"), function () {
            external.callMessage({
                "funcNo": "50101",
                "moduleName": "feedback"
            });
        });

        // 返回
        appUtils.bindEvent($(_pageId + " a.icon_back"), function () {
            if (appUtils.getSStorageInfo("hall_isDirectExit") == "true") {   // 这说明不是从“我”模块的首页进来的
                appUtils.clearSStorage();                                  // 是从其他入口绕过首页直接进来的，所以调接口退出“我”模块
                external.callMessage({
                    "funcNo": "70008",
                    "moduleName": "commonlocal"
                });
            } else {                                                        // 正常途径，从“我”模块首页进入“服务大厅”
                appUtils.pageBack();
            }
        });
    }

    /* 销毁 */
    function destroy() {
        mobileService.destroy();
    }

    // 获取客户电话
    function getCSTelephone() {
        var csTelephone = appUtils.getSStorageInfo("csTelephone");  // 客服电话
        if (!csTelephone) {
            mobileService.getCustomerServiceTelephone({}, function (data) {
                var results = data.results;
                if (data.error_no == "0" && results.length > 0) {
                    appUtils.setSStorageInfo("csTelephone", results[0].mobile_no);
                } else {
                    layerUtils.iLoading(false);
                    layerUtils.iAlert(data.error_info);
                }
            });
        }
    }

    var serviceHall = {
        "init": init,
        "bindPageEvent": bindPageEvent,
        "destroy": destroy
    };
    module.exports = serviceHall;
});