﻿define(function (require, exports, module) {
    /* 私有业务模块的全局变量 begin */
    var appUtils = require("appUtils"),
        layerUtils = require("layerUtils"),
        gconfig = require("gconfig"),
        global = gconfig.global,
        mobileService = require("mobileService"),
        _pageId = "#me_takePosition";

    var type = "";   //stock 股票，  otc 场外基金

    function init() {
        type = appUtils.getPageParam("type");
        if (type === "stock") {
            queryStockPosition();
        }
        else if (type === "otc") {
            queryOTCPosition();
        }
    }

    /* 查询股票持仓 */
    function queryStockPosition() {
        var param = {
            "fund_account": appUtils.getSStorageInfo("fund_account"),
            "client_id": appUtils.getSStorageInfo("client_id"),
            "branch_no": appUtils.getSStorageInfo("branch_no")
        };
        mobileService.queryMyPosition(param, function (data) {
            var error_no = data.error_no;
            var error_info = data.error_info;
            if (error_no == "0") {
                showStockPosition(data.results);   //显示股票持仓信息
            }
            else {
                layerUtils.iLoading(false);
                layerUtils.iAlert(error_info);
            }
        });
    }

    /* 显示股票持仓信息 */
    function showStockPosition(results) {
        var htmlStr = "<tr><th width='25%'>市值</th> <th width='25%'>盈亏</th> <th width='25%'>持仓/可用</th> <th width='25%'>成本/现价</th></tr>";
        for (var i = 0, len = results.length; i < len; i++) {
            var last_price = new Number(results[i].last_price),
                cost_price = new Number(results[i].cost_price),
                ratio = cost_price == 0.00 ? 0.00 : (last_price - cost_price) / cost_price;
            htmlStr += "<tr><td><h5>" + results[i].stock_name + "</h5><p>" + results[i].market_value + "</p></td>"
                + "<td class='" + (ratio >= 0.00 ? "profit" : "loss") + "'><p>" + results[i].income_balance + "</p><p>" + formatscale(ratio) + "</p></td>"
                + "<td><p>" + results[i].current_amount + "</p><p>" + results[i].enable_amount + "</p></td>"
                + "<td><p>" + results[i].cost_price + "</p><p>" + results[i].last_price + "</p></td></tr>";
        }
        $(_pageId + " .position_table").html(htmlStr);
    }

    /* 查询场外基金持仓 */
    function queryOTCPosition() {
        var param = {
            "fund_account": appUtils.getSStorageInfo("fund_account"),
            "client_id": appUtils.getSStorageInfo("client_id")
        }
        mobileService.queryOTCPosition(param, function (data) {
            var error_no = data.error_no;
            var error_info = data.error_info;
            if (error_no == "0") {
                showOTCPosition(data.results);  //显示场外基金持仓信息
            }
            else {
                layerUtils.iLoading(false);
                layerUtils.iAlert(error_info);
            }
        });

    }

    /* 显示场外基金持仓信息 */
    function showOTCPosition(results) {
        var htmlStr = "<tr><th width='25%'>市值</th> <th width='25%'>盈亏</th> <th width='25%'>持仓/可用</th> <th width='25%'>基金公司</th></tr>";
        for (var i = 0, len = results.length; i < len; i++) {
            var income_balance = new Number(results[i].income_balance);
            htmlStr += "<tr><td><h5>" + results[i].fund_name + "</h5><p>" + results[i].market_value + "</p></td>"
                + "<td class='" + (income_balance > 0 ? "profit" : "loss") + "'><p>" + results[i].income_balance + "</p></td>"
                + "<td><p>" + results[i].current_share + "</p><p>" + results[i].enable_shares + "</p></td>"
                + "<td><p>" + results[i].fund_company + "</p></td></tr>";
        }
        $(_pageId + " .position_table").html(htmlStr);
    }

    function bindPageEvent() {
        //返回
        appUtils.bindEvent($(_pageId + " .icon_back"), function () {
            appUtils.pageBack();
//            appUtils.pageInit("me/takePosition", "me/bondAccount", {});
        });
    }

    //销毁
    function destroy() {
        mobileService.destroy();
    }

    /*格式  %   */
    function formatscale(s, n) {
        n = n > 0 && n <= 20 ? n : 2;
        s = parseFloat((s + "").replace(/[^\d\.-]/g, ""));
        s = (s * 100).toFixed(n) + "";
        var l = s.split(".")[0].split("").reverse(), r = s.split(".")[1];
        t = "";
        for (i = 0; i < l.length; i++) {
            t += l[i] + ((i + 1) % 3 == 0 && (i + 1) != l.length ? "," : "");
        }
        return t.split("").reverse().join("") + "." + r + "%";
    }

    var takePosition = {
        "init": init,
        "bindPageEvent": bindPageEvent,
        "destroy": destroy
    };
    module.exports = takePosition;
});
