﻿define(function (require, exports, module) {
    /* 私有业务模块的全局变量 begin */
    var mobileService = require("mobileService");
    var appUtils = require("appUtils");
    var layerUtils = require("layerUtils");
    var gconfig = require("gconfig");
    var validatorUtil = require("validatorUtil");
    var _pageId = "#twoFinancial_twoFinancial";

    var ratio = 0;
    var results = null;

    function init() {
        $(_pageId + " .text-center").text(appUtils.getSStorageInfo("client_name"));                 //用户名
        $(_pageId + " .info_all #zjAccount").text(appUtils.getSStorageInfo("fund_account"));        //证券账户

        // 查询两融信息的入参
        var param = {
            "client_id": appUtils.getSStorageInfo("client_id")
        };
        queryTFInfo(param);  //查询两融信息
    }

    /* 查询两融信息 */
    function queryTFInfo(param) {
        mobileService.queryTwoFinancial(param, function (data) {
            var error_no = data.error_no;
            var error_info = data.error_info;
            if (error_no == 0) {
                $(_pageId + " #login_div").hide();   //隐藏密码框

                results = data.results;
                var total_assets = new Number(results[0].total_assets);   // 信用账户总资产
                var total_debit = new Number(results[0].total_debit);     // 总负债
                ratio =results[0].per_assurescale_value;// total_assets / total_debit;                       // 维持担保比例

                var fin_debit = new Number(results[0].fin_debit);         // 融资负债
                var fin_ratio = fin_debit / total_debit;

                var slo_debit = new Number(results[0].slo_debit);         // 融券负债
                var slo_ratio = slo_debit / total_debit;

                var param = {
                    "#wcdb_ratio": ratio,    // 维持担保比例formatscale(ratio + "")
                    ".all_data": results[0].total_assets,      // 信用总资产
                    "#zfuzhai": results[0].total_debit,        // 总负债
                    "#jzc": results[0].net_asset,              // 净资产
                    "#zyk": results[0].total_profit,           // 净资产
                    "#kybzj": results[0].enable_bail_balance,  // 可用保证金
                    "#amount1": results[0].fin_debit,          // 融资负债
                    "#percent1": formatscale(fin_ratio + ""),  // 比例
                    "#amount2": results[0].slo_debit,          // 融券负债
                    "#percent2": formatscale(slo_ratio + "")   // 比例
                }

                //将参数显示到页面
                for (var id in param) {
                    $(_pageId + " " + id).text(param[id]);
                }

                if (ratio < 1.30) {
                    $(_pageId + " .my_navlist ul").attr("class", "color03");
                }
                else if (ratio < 1.50) {
                    $(_pageId + " .my_navlist ul").attr("class", "color02");
                }
                else {
                    $(_pageId + " .my_navlist ul").attr("class", "color04");
                }

            }
            else if (error_no == "100309") {         //需要输入两融密码
                $(_pageId + " #login_div").show();   //显示密码框
            }
            else {
                layerUtils.iLoading(false);
                layerUtils.iAlert(error_info, -1);
            }
        });
    }

    function bindPageEvent() {
        // 返回
        appUtils.bindEvent($(_pageId + " .icon_back"), function () {
            appUtils.pageBack();
            // appUtils.pageInit("twoFinancial/twoFinancial", "me/myIndexYes", {});
        });

        // 维持担保比例
        appUtils.bindEvent($(_pageId + " .my_navlist ul li"), function () {
            if (results && results.length > 0) {
                appUtils.setSStorageInfo("tf_total_debit", results[0].total_debit);
                appUtils.setSStorageInfo("tf_ratio", ratio);
                appUtils.setSStorageInfo("total_assets", results[0].total_assets);
                appUtils.setSStorageInfo("fetch_balance", results[0].fetch_balance);
                appUtils.pageInit("twoFinancial/twoFinancial", "twoFinancial/showCollateralRatio", {});
            }

        });

        // 负债
        appUtils.bindEvent($(_pageId + " #debt"), function () {
            if (results && results.length > 0) {
                appUtils.pageInit("twoFinancial/twoFinancial", "twoFinancial/detailsOfDebt", {});
            }
        });

        // 确认按钮
        appUtils.bindEvent($(_pageId + " .ce_btn a"), function () {
            var password = $(_pageId + " #password").val();
            if (validatorUtil.isEmpty(password)) {
                layerUtils.iAlert("请输入密码");
                return;
            }

            var param = {
                "client_id": appUtils.getSStorageInfo("client_id"),
                "isCheckPWD": "1",
                "password": password
            };

            appUtils.setSStorageInfo("password", password);
            queryTFInfo(param);   //查询两融信息
        });
    }

    //销毁
    function destroy() {
        mobileService.destroy();
    }

    /*格式  %   */
    function formatscale(s, n) {
        n = n > 0 && n <= 20 ? n : 2;
        s = parseFloat((s + "").replace(/[^\d\.-]/g, ""));
        s = (s * 100).toFixed(n) + "";
        var l = s.split(".")[0].split("").reverse(), r = s.split(".")[1];
        t = "";
        for (i = 0; i < l.length; i++) {
            t += l[i] + ((i + 1) % 3 == 0 && (i + 1) != l.length ? "," : "");
        }
        return t.split("").reverse().join("") + "." + r + "%";
    }

    var twoFinancial = {
        "init": init,
        "bindPageEvent": bindPageEvent,
        "destroy": destroy
    };
    module.exports = twoFinancial;
});
