/**
 * 手机前端service层调用接口
 **/
define(function (require, exports, module) {
    var appUtils = require("appUtils");
    var gconfig = require("gconfig");
    var global = gconfig.global;
    var service = require("service");
    var external = require("external");
    var serviceSingleton = new service.Service();

    /********************************公共代码部分********************************/
    function commonInvoke(paraMap, callback, ctrlParam, reqParamVo) {
        if (!reqParamVo) {
            reqParamVo = new service.ReqParamVo();
            reqParamVo.setUrl(global.serverPath);
        }
        reqParamVo.setReqParam(paraMap);
        ctrlParam = ctrlParam ? ctrlParam : {};
        reqParamVo.setIsLastReq(ctrlParam.isLastReq);
        reqParamVo.setIsAsync(ctrlParam.isAsync);
        reqParamVo.setIsShowWait(ctrlParam.isShowWait);
        reqParamVo.setTimeOutFunc(ctrlParam.timeOutFunc);
        reqParamVo.setIsShowOverLay(ctrlParam.isShowOverLay);
        reqParamVo.setTipsWords(ctrlParam.tipsWords);
        reqParamVo.setDataType(ctrlParam.dataType);
        reqParamVo.setIsGlobal(ctrlParam.isGlobal);
        reqParamVo.setProtocol(ctrlParam.protocol);
        serviceSingleton.invoke(reqParamVo, callback);
    }

    function destroy() {
        serviceSingleton.destroy();
    }

    var mobileService = {
        "getInstance": getInstance, //为了避免以前调用getInstance方法报错
        "destroy": destroy
    };

    function getInstance() {
        return mobileService;
    }

    module.exports = mobileService;

    /* 获取站点数据 */
    function getOpStation() {
        var opStation = appUtils.getSStorageInfo("op_station");
        if (opStation) {
            return opStation;
        }
        var channelNo = " "; // 通道编号
        var ipAddr = " "; // ip
        var macAddr = " "; // mac
        var hardId = " "; // 硬盘序列号（硬件id）
        var cpuId = " "; // cpu 序列号
        var mobileNo = " "; // 手机号
        var hardIdentifier = " "; //硬件特征码
        var source = " "; // 来源
        var other = " "; // 其他

        if (iBrowser.android) {
            channelNo = "1";
        } else if (iBrowser.iPad || iBrowser.iPhone || iBrowser.ios) {
            channelNo = "2";
        } else if (iBrowser.pc) {
            channelNo = "0";
        }
        if (gconfig.platform != "0") {
            var mobileNoInfo = external.callMessage({
                "funcNo": "50043",
                "key": "mobilePhone"
            }); // 电话号码
            if (mobileNoInfo.error_no == "0") {
                mobileNo = mobileNoInfo.results[0].value;
            }
            var hardIdInfo = external.callMessage({
                "funcNo": "50022"
            }); //设备唯一码
            if (hardIdInfo.error_no == "0") {
                hardIdentifier = hardIdInfo.results[0].deviceToken;
            }
            var ipAddrInfo = external.callMessage({
                "funcNo": "50023"
            }); //设备IP地址
            if (ipAddrInfo.error_no == "0") {
                ipAddr = ipAddrInfo.results[0].ip;
            }
            var macAddrInfo = external.callMessage({
                "funcNo": "50024"
            }); //设备MAC地址
            if (macAddrInfo.error_no == "0") {
                macAddr = macAddrInfo.results[0].mac;
            }
            var versionInfo = external.callMessage({
                "funcNo": "50010"
            }); //应用版本号
            if (versionInfo.error_no == "0") {
                other = versionInfo.results[0].version;
            }
        }
        source = global.opStationInfo; //来源
        var aOpStation = [];
        aOpStation.push(channelNo);
        aOpStation.push("|");
        aOpStation.push(ipAddr);
        aOpStation.push("|");
        aOpStation.push(macAddr);
        aOpStation.push("|");
        aOpStation.push(hardId);
        aOpStation.push("|");
        aOpStation.push(cpuId);
        aOpStation.push("|");
        aOpStation.push(mobileNo);
        aOpStation.push("|");
        aOpStation.push(hardIdentifier);
        aOpStation.push("|");
        aOpStation.push(source);
        aOpStation.push("|");
        aOpStation.push(other);

        opStation = aOpStation.join("");
        appUtils.setSStorageInfo("op_station", opStation);
        return opStation;   // "通道编号|IP地址|MAC地址|硬盘序列号|CPU序列号|手机号码|硬件特征码|来源|其他"
    }

    /********************************应用接口开始********************************/
    /**
     * 华安云柜台登陆接口
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     *    isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.login = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100300";
        paraMap["fund_account"] = param.login_id;
        paraMap["password"] = param.pwd_value;
        paraMap["imgCode"] = param.imgCode;
        commonInvoke(paraMap, callback, ctrlParam);
    };
    /**
     * 华安云柜台客户信息查询
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     *    isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.userInfo = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100301";
        paraMap["fund_account"] = param.fund_account;
        paraMap["client_id"] = param.client_id;
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 华安云柜台证券股票详情
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     *    isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.queryStkAccount = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100302";
        paraMap["client_id"] = param.client_id;
        paraMap["fund_account"] = param.fund_account;
        paraMap["op_station"] = getOpStation();
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 华安云柜台银行卡管理(100303)
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     *    isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.bankManages = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100303";
        paraMap["fund_account"] = param.fund_account;
        paraMap["client_id"] = param.client_id;
        paraMap["bank_type"] = param.bank_type;
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 华安云柜台客户修改密码
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     *    isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.updateLodingPwd = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100305";
        paraMap["fund_account"] = param.fund_account;
        paraMap["client_id"] = param.client_id;
        paraMap["password"] = param.passwords;
        paraMap["password_old"] = param.password_old;
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 华安云柜台持仓信息
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     *    isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.queryMyPosition = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100307";
        paraMap["fund_account"] = param.fund_account;
        paraMap["client_id"] = param.client_id;
        paraMap["branch_no"] = param.branch_no;
        paraMap["op_station"] = getOpStation();
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 查询客户账户信息(100306)
     * @param param
     * @param callback
     * @param ctrlParam
     */
    mobileService.queryAccountInfo = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100306";
        paraMap["client_id"] = param.client_id;
        paraMap["branch_no"] = param.branch_no;
        paraMap["op_station"] = getOpStation();
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 华安云柜台资金明细(100308)
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     *    isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.queryBillInfo = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100308";
        paraMap["fund_account"] = param.fund_account;
        paraMap["client_id"] = param.client_id;
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 华安云柜台两融-----信用资产
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     *    isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.queryTwoFinancial = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100309";
        paraMap["client_id"] = param.client_id;
        paraMap["isCheckPWD"] = param.isCheckPWD;
        paraMap["password"] = param.password;
        paraMap["op_station"] = getOpStation();
        commonInvoke(paraMap, callback, ctrlParam);
    };
    /**
     * 华安云柜台两融-----信用资产
     * @param param json格式入参
     * @param callback 回调处理
     * @param ctrlParam json格式控制参数，包括protocol、isLastReq、isAsync、isShowWait、
     * isShowOverLay、tipsWords、timeOutFunc、dataType、isGlobal
     */
    mobileService.queryAccountBack = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100310";
        paraMap["branch_no"] = param.branch_no;
        paraMap["fund_account"] = param.fund_account;
        paraMap["client_id"] = param.client_id;
        paraMap["start_date"] = param.start_date;
        paraMap["end_date"] = param.end_date;
        paraMap["password"] = param.password;
        paraMap["packaged_type"] = param.packaged_type;
        paraMap["op_station"] = getOpStation();
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 基金持仓查询(100311)
     * @param param
     * @param callback
     * @param ctrlParam
     */
    mobileService.queryOTCPosition = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100311";
        paraMap["fund_account"] = param.fund_account;
        paraMap["client_id"] = param.client_id;
        commonInvoke(paraMap, callback, ctrlParam);
    };

    mobileService.queryDetailsOfDebt = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100312";
        paraMap["client_id"] = param.client_id;
        paraMap["password"] = param.password;
        paraMap["op_station"] = getOpStation();
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 上传头像到服务器(100313)
     * @param  client_id  客户ID
     * @param  img_type   必须传入8
     * @param  img_data   图片base64
     */
    mobileService.uploadPhoto = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100313";
        paraMap["client_id"] = param.client_id;
        paraMap["img_type"] = param.img_type;
        paraMap["img_data"] = param.img_data;
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 获取头像base64数据(100314)
     * @param  client_id  客户ID
     */
    mobileService.getPhoto = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100314";
        paraMap["client_id"] = param.client_id;
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 修改昵称(100315)
     * @param  user_id   客户ID
     * @param  day_name  昵称
     */
    mobileService.modifyNickname = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100315";
        paraMap["user_id"] = param.user_id;
        paraMap["day_name"] = param.day_name;
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 获取昵称(100316)
     * @param  user_id   客户ID
     */
    mobileService.queryNickname = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100316";
        paraMap["user_id"] = param.user_id;
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 查询绑定的关联账号(100317)
     * @param  mobile_no  激活手机号
     */
    mobileService.queryBindAccount = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100317";
        paraMap["mobile_no"] = param.mobile_no;
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 绑定关联的账号(100318)
     * @param  mobile_no    激活手机号
     * @param  client_id    客户ID
     * @param  client_name  客户姓名
     */
    mobileService.bindAccount = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100318";
        paraMap["mobile_no"] = param.mobile_no;
        paraMap["client_id"] = param.client_id;
        paraMap["client_name"] = param.client_name;
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 解绑关联的账号(100319)
     * @param  mobile_no  激活手机号
     * @param  client_id  客户ID
     */
    mobileService.unbindAccount = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100319";
        paraMap["mobile_no"] = param.mobile_no;
        paraMap["client_id"] = param.client_id;
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 查询栏目及问题(100320)
     */
    mobileService.queryQuestionList = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100320";
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 查询问题内容(100321)
     */
    mobileService.queryContentOfQuestion = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "100321";
        paraMap["ques_id"] = param.ques_id;
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /**
     * 获取客服电话(200000)
     */
    mobileService.getCustomerServiceTelephone = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "200000";
        commonInvoke(paraMap, callback, ctrlParam);
    };

    /*******************************理财接口********************************/
    /**
     * 功能  加密(1000000)
     */
    mobileService.getRSAKey = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "1000000";
        var reqParamVo = new service.ReqParamVo();

        reqParamVo.setUrl(global.serverPath_mall);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo);
    }

    /**
     * 功能 用户登陆
     */
    mobileService.loginyanzhen = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "1000010";
        paraMap["login_value"] = param.login_value;
        paraMap["login_pwd"] = param.login_pwd;
        paraMap["login_type"] = param.login_type;
        paraMap["fund_account"] = param.fund_account;

        var reqParamVo = new service.ReqParamVo();
        reqParamVo.setUrl(global.serverPath_mall);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

    }
    /**
     * 功能  理财份额查询(1000183)
     */
    mobileService.secumShareQry = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "1000183";
        paraMap["fund_account"] = param.fund_account;
        paraMap["login_pwd"] = param.login_pwd;
        paraMap["product_type"] = param.product_type;
        paraMap["page"] = param.page;//当前页
        paraMap["numPerPage"] = param.numPerPage;//每页显示最大记录条数

        var reqParamVo = new service.ReqParamVo();

        reqParamVo.setUrl(global.serverPath_mall);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

    }

    /**
     * 功能  证券理财产品申赎委托查询(1000184)
     */
    mobileService.secumEntrustQry = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "1000184";
        paraMap["fund_account"] = param.fund_account;
        paraMap["login_pwd"] = param.login_pwd;
        paraMap["product_type"] = param.product_type;
        paraMap["page"] = param.page;//当前页
        paraMap["numPerPage"] = param.numPerPage;//每页显示最大记录条数

        var reqParamVo = new service.ReqParamVo();

        reqParamVo.setUrl(global.serverPath_mall);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

    }
    /**
     * 功能  产品个人资产总额收益查询(1000185)
     */
    mobileService.fundProdToalasset = function (param, callback, ctrlParam) {
        var paraMap = {};
        paraMap["funcNo"] = "1000185";
        paraMap["fund_account"] = param.fund_account;
        paraMap["client_id"] = param.client_id;
        paraMap["login_pwd"] = param.login_pwd;

        var reqParamVo = new service.ReqParamVo();

        reqParamVo.setUrl(global.serverPath_mall);
        commonInvoke(paraMap, callback, ctrlParam, reqParamVo);

    };

    /********************************理财接口********************************/
    /********************************应用接口结束********************************/
});